(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    164971,       3791]
NotebookOptionsPosition[    154661,       3504]
NotebookOutlinePosition[    159058,       3599]
CellTagsIndexPosition[    157836,       3576]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
GraphicsTools and MechanicsTools are simple packages that execute code \
without creating a context.  Since all functions are self-contained and do \
not require any internal functions there is no real advantage in creating a \
context.\
\>", "Text",
 CellChangeTimes->{{3.623894031784239*^9, 3.623894092759953*^9}, {
  3.664324671103569*^9, 3.6643246865836163`*^9}, {3.6643247224410267`*^9, 
  3.664324774460073*^9}, {3.6643290510290728`*^9, 3.6643290600578127`*^9}, {
  3.6643291340834637`*^9, 3.664329193952619*^9}}],

Cell[BoxData[{
 RowBox[{"<<", "GraphicsTools`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "MechanicsTools`"}]}], "Input",
 CellChangeTimes->{{3.623845708402197*^9, 3.6238457190678596`*^9}, {
  3.623873904942814*^9, 3.6238739081645403`*^9}, {3.664324810139834*^9, 
  3.6643248130528793`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"?", "GraphicsTools"}], "\n", 
 RowBox[{"?", "MechanicsTools"}]}], "Input",
 CellChangeTimes->{{3.623845708402197*^9, 3.623845729357972*^9}, 
   3.664452055235365*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"GraphicsTools is a package containing the following functions: \
  \\n    LabeledArrow, LabeledSegment, DoubleArrow, AddArrow, \
SimpleArrowheads, PerpendicularLabel, AngleLabel, Polar, Spherical, Angle, \
CoordinateAxes, AxesTicks, Projection3D, CoordinateProjection3D, ShadedLine, \
LinePolygonMap, LinePolygonMappingRules, DrawParameterizedCurve, \
EuclideanMap2D, SimpleVectorArray, MinPolynomial, ColorShade, GrayShade, \
LinesFromPlot, LinetoAxis, LinetoBothAxes, LabeledLinetoAxis, SecantLine, \
TangentLine, PlotAndShade, MakeList, FadeOut\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.6644520675924463`*^9},
 CellTags->"Info-a2e2a8dc-467a-4e25-b3e4-bf95cf1af882"],

Cell[BoxData[
 StyleBox["\<\"MechanicsTools is a supplement to GraphicsTools containing the \
following functions:   \\n    RoundedBox, CubicSmoothShift, PolygonBelowLine, \
Spring, Pulley, StickMan, SimpleCar, SimpleTruck, GrayBlue, NColor, WColor, \
TColor, fColor\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.664452067713831*^9},
 CellTags->"Info-afa75f55-c95b-4435-b8fb-fd78f5fb709d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["LabeledArrow, LabeledSegment, DoubleArrow and CoordinateAxes", \
"Subsection",
 CellChangeTimes->{{3.622918985512065*^9, 3.622918997990827*^9}, {
  3.623845792825062*^9, 3.6238458188151417`*^9}, {3.623847424188937*^9, 
  3.6238474429380198`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "LabeledArrow"}]], "Input",
 CellChangeTimes->{{3.623845866908375*^9, 3.623845873110148*^9}}],

Cell[BoxData[
 StyleBox["\<\"LabeledArrow[tail:{0,0},tip,label,opts] gives an Arrow from \
tail to tip with a string, 'label', offset from the center.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6644520719172583`*^9},
 CellTags->"Info-b0807b79-7460-44b9-9bf9-f42a7330a29d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arrowheads", "[", ".15", "]"}], ",", 
     RowBox[{"LabeledArrow", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       "\"\<\!\(\*OverscriptBox[\(A\), \(\[RightVector]\)]\)\>\""}], "]"}]}], 
    "}"}], ",", 
   RowBox[{"BaseStyle", "->", 
    RowBox[{"{", 
     RowBox[{"12", ",", 
      RowBox[{"FontFamily", "->", "\"\<Times\>\""}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "200"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.623845909280053*^9, 3.62384601741181*^9}, {
  3.623846533024517*^9, 3.623846533471058*^9}, {3.6238471128202753`*^9, 
  3.623847121121025*^9}, {3.664452183214884*^9, 3.6644521986760883`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Arrowheads[0.15], 
   InsetBox["\<\"\\!\\(\\*OverscriptBox[\\(A\\), \
\\(\[RightVector]\\)]\\)\"\>", NCache[
    Offset[{(-3) 5^Rational[1, 2], 6 5^Rational[1, 2]}, {1., 0.5}], 
     Offset[{-6.708203932499369, 13.416407864998739`}, {1., 0.5}]]], 
   ArrowBox[{{0, 0}, {2, 1}}]},
  BaseStyle->{12, FontFamily -> "Times"},
  ImageSize->200]], "Output",
 CellChangeTimes->{3.664452074381287*^9, 3.664452199613977*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"LabeledArrow", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], ",", 
      "\"\<\!\(\*OverscriptBox[\(A\), \(\[RightVector]\)]\)\>\"", ",", 
      RowBox[{"TextPosition", "\[Rule]", "1"}], ",", 
      RowBox[{"TextOffset", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{".75", ",", "0"}], "}"}]}], ",", 
      RowBox[{"ArrowDirectives", "\[Rule]", 
       RowBox[{"Arrowheads", "[", ".15", "]"}]}]}], "]"}], "}"}], ",", 
   RowBox[{"BaseStyle", "->", 
    RowBox[{"{", 
     RowBox[{"12", ",", 
      RowBox[{"FontFamily", "->", "\"\<Times\>\""}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "200"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.623845909280053*^9, 3.62384601741181*^9}, {
   3.623846083330921*^9, 3.62384609565031*^9}, {3.623846462864562*^9, 
   3.623846486582629*^9}, {3.623846545421104*^9, 3.623846563824851*^9}, {
   3.6238466058496923`*^9, 3.6238466323581533`*^9}, 3.623847140538794*^9, {
   3.6644522135348673`*^9, 3.664452215516728*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Arrowheads[0.15], 
   InsetBox["\<\"\\!\\(\\*OverscriptBox[\\(A\\), \
\\(\[RightVector]\\)]\\)\"\>", 
    Offset[{10.062305898749054`, 5.031152949374527}, {2, 1}]], 
   ArrowBox[{{0, 0}, {2, 1}}]},
  BaseStyle->{12, FontFamily -> "Times"},
  ImageSize->200]], "Output",
 CellChangeTimes->{3.664452082206772*^9, 3.6644522165718107`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "LabeledArrow", "]"}]], "Input",
 CellChangeTimes->{{3.6238460430540752`*^9, 3.6238460516886806`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TextOffset", "\[Rule]", "1"}], ",", 
   RowBox[{"AbsoluteTextOffset", "\[Rule]", "True"}], ",", 
   RowBox[{"ArrowDirectives", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"TextPosition", "\[Rule]", "0.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6644520867403383`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"W", "=", "50"}], "}"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Arrowheads", "[", ".1", "]"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\[Theta]", "=", 
           RowBox[{"Angle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"6", ",", "4"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Rotate", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"CoordinateAxes", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "48"}], ",", "53"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "25"}], ",", "40"}], "}"}], ",", 
                 RowBox[{"ArrowSize", "\[Rule]", "3"}]}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Text", "[", 
                RowBox[{"\"\<\[UpTee]\>\"", ",", 
                 RowBox[{"{", 
                  RowBox[{"53", ",", 
                   RowBox[{"-", "5"}]}], "}"}]}], "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{"\"\<\[DoubleVerticalBar]\>\"", ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "5"}], ",", "40"}], "}"}]}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"AbsoluteDashing", "[", "3", "]"}], ",", 
                 RowBox[{"Line", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"W", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", "0"}], 
                    "}"}]}], ",", 
                    RowBox[{"W", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}], ",", 
                    RowBox[{"W", " ", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}]}], "}"}],
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"AngleLabel", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"180", "\[Degree]"}], "-", "\[Theta]"}], ",", 
                   RowBox[{"180", "\[Degree]"}]}], "}"}], ",", "15", ",", 
                 "23", ",", "\"\<\[Theta]\>\""}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"NColor", ",", "\n", "\t\t\t", 
                 RowBox[{"LabeledArrow", "[", 
                  RowBox[{
                   RowBox[{"W", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], 
                    "}"}]}], ",", "\"\<\!\(\*
StyleBox[\"N\",
FontSlant->\"Italic\"]\)\>\"", ",", 
                   RowBox[{"TextOffset", "\[Rule]", 
                    RowBox[{"-", ".6"}]}]}], "]"}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"LabeledArrow", "[", " ", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"30", ",", "5"}], "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"30", ",", 
                   RowBox[{"5", "+", "25"}]}], "}"}], ",", "\"\<\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\>\"", ",", 
                 RowBox[{"TextOffset", "\[Rule]", 
                  RowBox[{"-", ".6"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
               
               RowBox[{"{", 
                RowBox[{"fColor", ",", 
                 RowBox[{"LabeledArrow", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "3.5"}], ",", "0"}], "}"}], ",", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "3.5"}], ",", "0"}], "}"}], "+", 
                    RowBox[{".8", "W", " ", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}]}], ",", 
                   "\"\<\!\(\*SubscriptBox[\(f\), \(k\)]\)\>\"", ",", 
                   RowBox[{"TextOffset", "\[Rule]", ".8"}], ",", 
                   RowBox[{"TextPosition", "\[Rule]", ".7"}]}], "]"}]}], 
                "}"}], ",", "\n", "\t\t", 
               RowBox[{"{", 
                RowBox[{"WColor", ",", 
                 RowBox[{"LabeledArrow", "[", 
                  RowBox[{
                   RowBox[{"W", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}], ",", 
                   "\"\<\!\(\*
StyleBox[\"m\",
FontSlant->\"Italic\"]\)\[ThinSpace]\!\(\*
StyleBox[\"g\",
FontSlant->\"Italic\"]\)\>\"", ",", 
                   RowBox[{"TextOffset", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"2.9", ",", 
                    RowBox[{"-", ".6"}]}], "}"}]}]}], "]"}], ",", "\n", 
                 "\t\t\t", 
                 RowBox[{"LabeledSegment", "[", 
                  RowBox[{
                   RowBox[{"W", " ", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}], ",", 
                   "\"\<\!\(\*
StyleBox[\"m\",
FontSlant->\"Italic\"]\)\[ThinSpace]\!\(\*
StyleBox[\"g\",
FontSlant->\"Italic\"]\)\[ThinSpace]sin\[ThinSpace]\[Theta]\>\"", ",", 
                   RowBox[{"TextOffset", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{".5", ",", 
                    RowBox[{"-", "1."}]}], "}"}]}]}], "]"}], ",", "\n", 
                 "\t\t\t", 
                 RowBox[{"LabeledSegment", "[", 
                  RowBox[{
                   RowBox[{"W", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", "0"}], 
                    "}"}]}], ",", "\"\<\!\(\*
StyleBox[\"m\",
FontSlant->\"Italic\"]\)\[ThinSpace]\!\(\*
StyleBox[\"g\",
FontSlant->\"Italic\"]\)\[ThinSpace]cos\[ThinSpace]\[Theta]\>\"", ",", 
                   RowBox[{"TextOffset", "\[Rule]", "1.6"}]}], "]"}]}], 
                "}"}]}], "}"}], "}"}], ",", 
            RowBox[{"\[Theta]", "+", 
             RowBox[{"90", "\[Degree]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], "]"}], "/.", 
          RowBox[{"t_Text", "\[RuleDelayed]", 
           RowBox[{"Rotate", "[", 
            RowBox[{"t", ",", 
             RowBox[{
              RowBox[{"-", "\[Theta]"}], "-", 
              RowBox[{"90", "\[Degree]"}]}]}], "]"}]}]}]}], "]"}]}], "\n", 
      "\t", "}"}], ",", 
     RowBox[{"BaseStyle", "->", 
      RowBox[{"{", 
       RowBox[{"12", ",", 
        RowBox[{"FontFamily", "->", "\"\<Times\>\""}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "50"}], ",", "50"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "60"}], ",", "50"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "200"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6238475555399714`*^9, 3.623847660026062*^9}, {
  3.623848048594041*^9, 3.623848062729768*^9}, {3.664452228015263*^9, 
  3.66445223043005*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Arrowheads[0.1], 
   GeometricTransformationBox[{{LineBox[{{-48, 0}, {53, 0}}], 
      LineBox[{{50, 1.5}, {53, 0}, {50, -1.5}}], LineBox[{{0, -25}, {0, 40}}],
       LineBox[{{1.5, 37}, {0, 40}, {-1.5, 37}}]}, 
     GeometricTransformationBox[
      InsetBox["\<\"\[UpTee]\"\>", {53, -5}], {{{-0.5547001962252291, 
       0.8320502943378437}, {-0.8320502943378437, -0.5547001962252291}}, 
       Center}], 
     GeometricTransformationBox[
      InsetBox["\<\"\[DoubleVerticalBar]\"\>", {-5, 40}], \
{{{-0.5547001962252291, 
       0.8320502943378437}, {-0.8320502943378437, -0.5547001962252291}}, 
       Center}], 
     {AbsoluteDashing[3], 
      LineBox[NCache[{{(-150) 13^Rational[-1, 2], 0}, {(-150) 
          13^Rational[-1, 2], 100 13^Rational[-1, 2]}, {
         0, 100 13^Rational[-1, 2]}}, {{-41.60251471689219, 
          0}, {-41.60251471689219, 27.735009811261456`}, {
         0, 27.735009811261456`}}]]}, {
      CircleBox[{0, 0}, 15, 
       NCache[{180 Degree - ArcCos[3 13^Rational[-1, 2]], 180 Degree}, {
        2.5535900500422257`, 3.141592653589793}]], 
      GeometricTransformationBox[
       InsetBox["\<\"\[Theta]\"\>", 
        NCache[{23 
          Cos[Rational[1, 2] (360 Degree - ArcCos[3 13^Rational[-1, 2]])], 23 
          Sin[Rational[1, 2] (360 Degree - ArcCos[
             3 13^Rational[-1, 2]])]}, {-22.013116609248215`, 
         6.665035419833898}]], {{{-0.5547001962252291, 
        0.8320502943378437}, {-0.8320502943378437, -0.5547001962252291}}, 
        Center}]}, 
     {AbsoluteThickness[2], 
      {RGBColor[0.7, 0, 0], 
       GeometricTransformationBox[
        InsetBox["\<\"\\!\\(\\*\\nStyleBox[\\\"N\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\"\>", 
         Offset[{0., -9.}, {20.801257358446094`, 0.}]], \
{{{-0.5547001962252291, 
         0.8320502943378437}, {-0.8320502943378437, -0.5547001962252291}}, 
         Center}], 
       ArrowBox[
        NCache[{{0, 0}, {150 13^Rational[-1, 2], 0}}, {{0, 0}, {
          41.60251471689219, 0}}]]}, {
       GeometricTransformationBox[
        InsetBox["\<\"\\!\\(\\*\\nStyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\"\>", Offset[{9., 0.}, {30., 17.5}]], {{{-0.5547001962252291, 
         0.8320502943378437}, {-0.8320502943378437, -0.5547001962252291}}, 
         Center}], ArrowBox[{{30, 5}, {30, 30}}]}, 
      {RGBColor[0.625, 0.5, 0], 
       GeometricTransformationBox[
        InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(f\\), \\(k\\)]\\)\"\>", 
         Offset[{-12., 0.}, {-3.5, 15.531605494306417`}]], \
{{{-0.5547001962252291, 
         0.8320502943378437}, {-0.8320502943378437, -0.5547001962252291}}, 
         Center}], ArrowBox[{{-3.5, 0}, {-3.5, 22.188007849009168`}}]}, 
      {RGBColor[
       0, 0, 0.7], {
        GeometricTransformationBox[
         InsetBox["\<\"\\!\\(\\*\\nStyleBox[\\\"m\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\[ThinSpace]\\!\\(\\*\\nStyleBox[\\\"g\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\"\>", 
          Offset[{-31.201886037669134`, 31.617911184838057`}, \
{-20.801257358446094`, 13.867504905630728`}]], {{{-0.5547001962252291, 
          0.8320502943378437}, {-0.8320502943378437, -0.5547001962252291}}, 
          Center}], 
        ArrowBox[
         NCache[{{0, 
           0}, {(-150) 13^Rational[-1, 2], 100 13^Rational[-1, 2]}}, {{0, 
           0}, {-41.60251471689219, 27.735009811261456`}}]]}, {
        GeometricTransformationBox[
         InsetBox["\<\"\\!\\(\\*\\nStyleBox[\\\"m\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\[ThinSpace]\\!\\(\\*\\nStyleBox[\\\"g\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\[ThinSpace]sin\[ThinSpace]\[Theta]\"\>", 
          Offset[{15., 7.5}, {0., 13.867504905630728`}]], \
{{{-0.5547001962252291, 
          0.8320502943378437}, {-0.8320502943378437, -0.5547001962252291}}, 
          Center}], 
        LineBox[NCache[{{0, 0}, {0, 100 13^Rational[-1, 2]}}, {{0, 0}, {
           0, 27.735009811261456`}}]]}, {
        GeometricTransformationBox[
         InsetBox["\<\"\\!\\(\\*\\nStyleBox[\\\"m\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\[ThinSpace]\\!\\(\\*\\nStyleBox[\\\"g\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\[ThinSpace]cos\[ThinSpace]\[Theta]\"\>", 
          Offset[{0., -24.}, {-20.801257358446094`, 0.}]], \
{{{-0.5547001962252291, 
          0.8320502943378437}, {-0.8320502943378437, -0.5547001962252291}}, 
          Center}], 
        LineBox[NCache[{{0, 0}, {(-150) 13^Rational[-1, 2], 0}}, {{0, 
           0}, {-41.60251471689219, 
            0}}]]}}}}, {{{-0.5547001962252291, -0.8320502943378437}, {
     0.8320502943378437, -0.5547001962252291}}, {0, 0}}]},
  BaseStyle->{12, FontFamily -> "Times"},
  ImageSize->200,
  PlotRange->{{-50, 50}, {-60, 50}}]], "Output",
 CellChangeTimes->{3.664452091672345*^9, 3.664452231554061*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DoubleArrow"}]], "Input",
 CellChangeTimes->{{3.664452368727147*^9, 3.664452369571203*^9}}],

Cell[BoxData[
 StyleBox["\<\"DoubleArrow[r1,r2,text,opts] draws a double arrow between r1 \
and r2 with text at center. The text is at the center of the gap. TextGap \
option must be adjusted to give room for the Text. TextGap->0 and TextOffset \
place the text away from the center. TextGap greater than one gives inward \
pointing arrows; this is useful for small gaps.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.66445237094411*^9},
 CellTags->"Info-f4460144-5bfb-4a6c-9dcd-e3fd64f530d7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"dashedLines", "=", 
      RowBox[{"a", "\[Function]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"AbsoluteDashing", "[", "2.5", "]"}], ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "a"}], "/", "2"}], ",", 
              RowBox[{"1", "/", "6"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "a"}], "/", "2"}], ",", 
              RowBox[{
               RowBox[{"-", "1"}], "/", "6"}]}], "}"}]}], "}"}], "]"}], ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", "/", "2"}], ",", 
              RowBox[{"1", "/", "6"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", "/", "2"}], ",", 
              RowBox[{
               RowBox[{"-", "1"}], "/", "6"}]}], "}"}]}], "}"}], "]"}]}], 
        "}"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"txt", "=", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<a\>\"", ",", "12", ",", "Italic", ",", 
        RowBox[{"FontFamily", "->", "\"\<Times\>\""}]}], "]"}]}]}], "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Arrowheads", "[", ".02", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"a", "=", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"dashedLines", "[", "a", "]"}], ",", 
           RowBox[{"DoubleArrow", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "a"}], "/", "2"}], ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"a", "/", "2"}], ",", "0"}], "}"}], ",", "txt", ",", 
             RowBox[{"TextGap", "\[Rule]", ".2"}]}], "]"}]}], "}"}]}], "]"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Translate", "[", 
        RowBox[{
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"a", "=", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"dashedLines", "[", "a", "]"}], ",", 
             RowBox[{"DoubleArrow", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], "/", "2"}], ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"a", "/", "2"}], ",", "0"}], "}"}], ",", "txt", ",", 
               
               RowBox[{"TextGap", "\[Rule]", ".2"}], ",", 
               RowBox[{"TextPosition", "\[Rule]", ".3"}]}], "]"}]}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"2.25", ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Translate", "[", 
        RowBox[{
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"a", "=", ".8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"dashedLines", "[", "a", "]"}], ",", 
             RowBox[{"DoubleArrow", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], "/", "2"}], ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"a", "/", "2"}], ",", "0"}], "}"}], ",", "txt", ",", 
               
               RowBox[{"TextGap", "\[Rule]", "0"}], ",", 
               RowBox[{"TextOffset", "\[Rule]", ".25"}]}], "]"}]}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"4.", ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Translate", "[", 
        RowBox[{
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"a", "=", ".5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"dashedLines", "[", "a", "]"}], ",", 
             RowBox[{"DoubleArrow", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], "/", "2"}], ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"a", "/", "2"}], ",", "0"}], "}"}], ",", "txt", ",", 
               
               RowBox[{"TextGap", "\[Rule]", "3"}]}], "]"}]}], "}"}]}], "]"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"5.5", ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Translate", "[", 
        RowBox[{
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"a", "=", ".15"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"dashedLines", "[", "a", "]"}], ",", 
             RowBox[{"DoubleArrow", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "a"}], "/", "2"}], ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"a", "/", "2"}], ",", "0"}], "}"}], ",", "txt", ",", 
               
               RowBox[{"TextGap", "\[Rule]", "7.5"}], ",", 
               RowBox[{"TextOffset", "\[Rule]", "2.5"}]}], "]"}]}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"7.25", ",", "0"}], "}"}]}], "]"}]}], "\[IndentingNewLine]",
       "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.62306393787908*^9, 3.6230639415186987`*^9}, {
   3.623064014166803*^9, 3.623064140562716*^9}, {3.623064223238758*^9, 
   3.623064715487952*^9}, {3.623064749176352*^9, 3.623064861240509*^9}, {
   3.623065127766684*^9, 3.623065241476223*^9}, {3.62306537486825*^9, 
   3.623065400051922*^9}, {3.623065569431745*^9, 3.6230655702925797`*^9}, {
   3.6230750140951023`*^9, 3.62307506391842*^9}, {3.623149272743803*^9, 
   3.623149505696643*^9}, {3.623891193805441*^9, 3.623891367585239*^9}, 
   3.623891513827886*^9, {3.6238918427736797`*^9, 3.6238921882438602`*^9}, {
   3.623892812248927*^9, 3.623892835836205*^9}, 3.6238929617734423`*^9, {
   3.664452245535206*^9, 3.664452276766337*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Arrowheads[0.02], {
    {AbsoluteDashing[2.5], 
     LineBox[NCache[{{-1, Rational[1, 6]}, {-1, Rational[-1, 6]}}, {{-1, 
         0.16666666666666666`}, {-1, -0.16666666666666666`}}]], 
     LineBox[NCache[{{1, Rational[1, 6]}, {1, Rational[-1, 6]}}, {{
        1, 0.16666666666666666`}, {1, -0.16666666666666666`}}]]}, {
     ArrowBox[{{-0.19999999999999996`, 0.}, {-1, 0}}], 
     ArrowBox[{{0.19999999999999996`, 0.}, {1, 0}}], InsetBox[
      StyleBox["\<\"a\"\>",
       StripOnInput->False,
       FontFamily->"Times",
       FontSize->12,
       FontSlant->Italic], {0., 0.}]}}, GeometricTransformationBox[{
     {AbsoluteDashing[2.5], 
      LineBox[NCache[{{-1, Rational[1, 6]}, {-1, Rational[-1, 6]}}, {{-1, 
          0.16666666666666666`}, {-1, -0.16666666666666666`}}]], 
      LineBox[NCache[{{1, Rational[1, 6]}, {1, Rational[-1, 6]}}, {{
         1, 0.16666666666666666`}, {1, -0.16666666666666666`}}]]}, {
      ArrowBox[{{-0.6000000000000001, 0.}, {-1, 0}}], 
      ArrowBox[{{-0.19999999999999996`, 0.}, {1, 0}}], InsetBox[
       StyleBox["\<\"a\"\>",
        StripOnInput->False,
        FontFamily->"Times",
        FontSize->12,
        FontSlant->Italic], {-0.4, 0.}]}}, {2.25, 0}], 
   GeometricTransformationBox[{
     {AbsoluteDashing[2.5], 
      LineBox[NCache[{{-0.4, Rational[1, 6]}, {-0.4, 
          Rational[-1, 6]}}, {{-0.4, 
        0.16666666666666666`}, {-0.4, -0.16666666666666666`}}]], 
      LineBox[NCache[{{0.4, Rational[1, 6]}, {0.4, Rational[-1, 6]}}, {{0.4, 
        0.16666666666666666`}, {0.4, -0.16666666666666666`}}]]}, {
      ArrowBox[{{0., 0.}, {-0.4, 0}}], ArrowBox[{{0., 0.}, {0.4, 0}}], 
      InsetBox[
       StyleBox["\<\"a\"\>",
        StripOnInput->False,
        FontFamily->"Times",
        FontSize->12,
        FontSlant->Italic], {0., 0.2}]}}, {4., 0}], 
   GeometricTransformationBox[{
     {AbsoluteDashing[2.5], 
      LineBox[NCache[{{-0.25, Rational[1, 6]}, {-0.25, 
          Rational[-1, 6]}}, {{-0.25, 
        0.16666666666666666`}, {-0.25, -0.16666666666666666`}}]], 
      LineBox[
       NCache[{{0.25, Rational[1, 6]}, {0.25, Rational[-1, 6]}}, {{0.25, 
        0.16666666666666666`}, {0.25, -0.16666666666666666`}}]]}, {
      ArrowBox[{{-0.75, 0.}, {-0.25, 0}}], ArrowBox[{{0.75, 0.}, {0.25, 0}}], 
      InsetBox[
       StyleBox["\<\"a\"\>",
        StripOnInput->False,
        FontFamily->"Times",
        FontSize->12,
        FontSlant->Italic], {0., 0.}]}}, {5.5, 0}], 
   GeometricTransformationBox[{
     {AbsoluteDashing[2.5], 
      LineBox[NCache[{{-0.075, Rational[1, 6]}, {-0.075, 
          Rational[-1, 6]}}, {{-0.075, 
        0.16666666666666666`}, {-0.075, -0.16666666666666666`}}]], 
      LineBox[NCache[{{0.075, Rational[1, 6]}, {0.075, Rational[-1, 6]}}, {{
        0.075, 0.16666666666666666`}, {0.075, -0.16666666666666666`}}]]}, {
      ArrowBox[{{-0.5625, 0.}, {-0.075, 0}}], 
      ArrowBox[{{0.5625, 0.}, {0.075, 0}}], InsetBox[
       StyleBox["\<\"a\"\>",
        StripOnInput->False,
        FontFamily->"Times",
        FontSize->12,
        FontSlant->Italic], {0., 0.375}]}}, {7.25, 0}]},
  ImageSize->400]], "Output",
 CellChangeTimes->{{3.664452247851426*^9, 3.664452277095806*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SimpleArrowheads", "Subsection",
 CellChangeTimes->{3.6238951376317463`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SimpleArrowheads"}]], "Input",
 CellChangeTimes->{{3.623894415098187*^9, 3.623894421961462*^9}}],

Cell[BoxData[
 StyleBox["\<\"SimpleArrowheads[w] gives the Arrowheads directive for a \
simple line arrowhead.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.664452291952464*^9},
 CellTags->"Info-952de8a6-885e-4dc4-b0d9-2c4f8a31ef1f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Arrowheads", "[", ".1", "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SimpleArrowheads", "[", "3", "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{".5", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{".5", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", ".1"}], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "125"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.623894569797398*^9, 3.6238946977419863`*^9}, {
  3.623894753808319*^9, 3.6238947600164022`*^9}, {3.623894815353779*^9, 
  3.623894915303605*^9}, {3.664452300580562*^9, 3.664452316099374*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Arrowheads[0.1], ArrowBox[{{0, 0}, {0, 1}}]}, 
   {Arrowheads[{{Automatic, Automatic, 
       GraphicsBox[{{
          LineBox[
           NCache[{{
              Rational[-3, 2], 
              Rational[3, 4]}, {0, 0}, {
              Rational[-3, 2], 
              Rational[-3, 4]}}, {{-1.5, 0.75}, {0, 
             0}, {-1.5, -0.75}}]]}}]}}], ArrowBox[{{0.5, 0}, {0.5, 1}}]}},
  ImageSize->125,
  PlotRange->{{-0.1, 1.1}, {Automatic, Automatic}}]], "Output",
 CellChangeTimes->{{3.664452293456012*^9, 3.664452316563283*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "SimpleArrowheads", "]"}]], "Input",
 CellChangeTimes->{3.664451613508791*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"WidthRatio", "\[Rule]", "1"}], ",", 
   RowBox[{"FilledArrow", "\[Rule]", "False"}], ",", 
   RowBox[{"ArrowDirectives", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"ArrowOffset", "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.664452322540415*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pulley", "Subsection",
 CellChangeTimes->{{3.622918985512065*^9, 3.622918997990827*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Pulley"}]], "Input",
 CellChangeTimes->{{3.664452339556025*^9, 3.664452344490324*^9}}],

Cell[BoxData[
 StyleBox["\<\"Pulley[center,base,R,opts] The radius R is the radius on which \
the string moves; the outside is larger by the options PulleyOversize.  The \
Option PulleyStyle is Disk by default. \
PulleyStyle->Spokes[{number,EmptyFraction},{InsideR,OutsideR}], where InsideR \
and OutsideR are factions of the Pulley radius, and Spokes[] and \
Spokes[{number,EmptyFraction}] uses SpokeDefaults for values. \
PulleyStyle->None shows no pulley and BarWidth->0 shows no bar; these can be \
used to build up complex arrangements\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.664452345551154*^9},
 CellTags->"Info-c8fcd507-db8b-4fb3-9955-bdee6420cc2f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Pulley", "]"}]], "Input",
 CellChangeTimes->{{3.623887371072439*^9, 3.623887381662704*^9}, 
   3.66445158759264*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"PulleyStyle", "\[Rule]", "Disk"}], ",", 
   RowBox[{"SpokeDefaults", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"10", ",", "0.4`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.2`", ",", "0.9`"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"BaseFraction", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"RimColor", "\[Rule]", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {GrayLevel[0.6], RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->GrayLevel[0.4],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification]}],
        PlotRangePadding->None],
       "GrayLevel[0.6]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0.6]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["GrayLevelColorValueSelector"], {
            0, {Left, Bottom}}, {Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     GrayLevel[0.6],
     Editable->False,
     Selectable->False]}], ",", 
   RowBox[{"PulleyColor", "\[Rule]", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {GrayLevel[0.7], RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->GrayLevel[0.4666666666666667],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification]}],
        PlotRangePadding->None],
       "GrayLevel[0.7]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0.7]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["GrayLevelColorValueSelector"], {
            0, {Left, Bottom}}, {Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     GrayLevel[0.7],
     Editable->False,
     Selectable->False]}], ",", 
   RowBox[{"BarColor", "\[Rule]", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {GrayLevel[0.6], RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->GrayLevel[0.4],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification]}],
        PlotRangePadding->None],
       "GrayLevel[0.6]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0.6]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["GrayLevelColorValueSelector"], {
            0, {Left, Bottom}}, {Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     GrayLevel[0.6],
     Editable->False,
     Selectable->False]}], ",", 
   RowBox[{"BarWidthScale", "\[Rule]", "0.3`"}], ",", 
   RowBox[{"BarCenterOversize", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"BarBaseOversize", "\[Rule]", "0"}], ",", 
   RowBox[{"RotationAngle", "\[Rule]", "0"}], ",", 
   RowBox[{"PulleyOversize", "\[Rule]", "1.05`"}], ",", 
   RowBox[{"RimLineDirectives", "\[Rule]", 
    RowBox[{"AbsoluteThickness", "[", "1", "]"}]}], ",", 
   RowBox[{"BarLineDirectives", "\[Rule]", 
    RowBox[{"AbsoluteThickness", "[", "1", "]"}]}], ",", 
   RowBox[{"InteriorLineDirectives", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.664452326438305*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Pulley", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Pulley", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"6", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6", ",", "3"}], "}"}], ",", "2", ",", 
       RowBox[{"PulleyStyle", "\[Rule]", 
        RowBox[{"Spokes", "[", "]"}]}]}], "]"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6229954461538754`*^9, 3.622995451698151*^9}, {
   3.6229957429043303`*^9, 3.622995811902334*^9}, {3.622995870101149*^9, 
   3.622995916437695*^9}, {3.6229966359985237`*^9, 3.622996646269911*^9}, {
   3.622998663000759*^9, 3.622998729342195*^9}, {3.62299876474193*^9, 
   3.62299878290244*^9}, 3.622998843124915*^9, {3.6229988987008953`*^9, 
   3.622998901927251*^9}, 3.6230009540645647`*^9, {3.623073908036936*^9, 
   3.6230739211631813`*^9}, {3.623111529259646*^9, 3.6231116009484673`*^9}, {
   3.623890513738303*^9, 3.623890520919683*^9}, {3.623890566284387*^9, 
   3.623890616678103*^9}}],

Cell[BoxData[
 GraphicsBox[{{GeometricTransformationBox[
     {GrayLevel[0.7], EdgeForm[AbsoluteThickness[1]], 
      DiskBox[{0, 0}, 2.1]}, {{{1, 0}, {0, 1}}, {0, 0}}], 
    {GrayLevel[0.6], EdgeForm[AbsoluteThickness[1]], 
     GeometricTransformationBox[
      RectangleBox[{-0.3, -0.3}, {3, 0.3}], {{{-1, 0}, {0, -1}}, {0, 0}}]}}, {
    GeometricTransformationBox[{
      {GrayLevel[0.7], 
       {EdgeForm[None], 
        DiskBox[{6, 0}, 2, {0.5026548245743669, 0.7539822368615503}], 
        DiskBox[{6, 0}, 2, {1.1309733552923256`, 1.382300767579509}], 
        DiskBox[{6, 0}, 2, {1.7592918860102842`, 2.0106192982974678`}], 
        DiskBox[{6, 0}, 2, {2.3876104167282426`, 2.6389378290154264`}], 
        DiskBox[{6, 0}, 2, {3.015928947446201, 3.267256359733385}], 
        DiskBox[{6, 0}, 2, {3.64424747816416, 3.8955748904513436`}], 
        DiskBox[{6, 0}, 2, {4.2725660088821185`, 4.523893421169302}], 
        DiskBox[{6, 0}, 2, {4.900884539600077, 5.152211951887261}], 
        DiskBox[{6, 0}, 2, {5.529203070318036, 5.7805304826052195`}], 
        DiskBox[{6, 0}, 2, {6.157521601035994, 6.408849013323178}]}, 
       {EdgeForm[None], DiskBox[{6, 0}, 0.4]}, 
       InterpretationBox[
        FilledCurveBox[{{
          BSplineCurve[{{6., -2.1}, {8.1, -2.1}, {8.1, 2.1}, {6., 2.1}, {3.9, 
            2.1}, {3.9, -2.1}, {6., -2.1}}, 
            SplineKnots -> {
             0, 0, 0, Rational[1, 4], Rational[1, 2], Rational[1, 2], 
              Rational[3, 4], 1, 1, 1}, 
            SplineWeights -> {2, 1, 1, 2, 1, 1, 2}, SplineDegree -> 2]}, {
          BSplineCurve[{{6., -1.8}, {7.8, -1.8}, {7.8, 1.8}, {6., 1.8}, {4.2, 
            1.8}, {4.2, -1.8}, {6., -1.8}}, 
            SplineKnots -> {
             0, 0, 0, Rational[1, 4], Rational[1, 2], Rational[1, 2], 
              Rational[3, 4], 1, 1, 1}, 
            SplineWeights -> {2, 1, 1, 2, 1, 1, 2}, SplineDegree -> 2]}}],
        Annulus[{6, 0}, {1.8, 2.1}]]}, CircleBox[{6, 0}, 1.8], 
      {AbsoluteThickness[1], CircleBox[{6, 0}, 2.1]}}, {{{1, 0}, {0, 1}}, {0, 
      0}}], 
    {GrayLevel[0.6], EdgeForm[AbsoluteThickness[1]], 
     GeometricTransformationBox[
      RectangleBox[{-0.3, -0.3}, {3, 0.3}], {{{0, -1}, {1, 0}}, {6, 0}}]}}},
  Frame->True,
  ImageSize->300]], "Output",
 CellChangeTimes->{3.664452328875449*^9, 3.664452386066606*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h", "=", "3"}], ",", 
     RowBox[{"HPulley", "=", "4.5"}], ",", 
     RowBox[{"HCeiling", "=", "6"}], ",", 
     RowBox[{"dim1", "=", 
      RowBox[{"{", 
       RowBox[{".4", ",", ".5"}], "}"}]}], ",", 
     RowBox[{"dim2", "=", 
      RowBox[{"{", 
       RowBox[{".5", ",", ".6"}], "}"}]}], ",", 
     RowBox[{"a", "=", ".2"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Animate", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", "=", 
         RowBox[{".5", " ", "a", " ", 
          SuperscriptBox["t", "2"]}]}], "}"}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"c1", "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", 
              RowBox[{
               RowBox[{".5", " ", 
                RowBox[{
                "dim1", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], "+", "x"}]}], "}"}]}], ",", 
           RowBox[{"c2", "=", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{
               RowBox[{".5", " ", 
                RowBox[{
                "dim1", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], "+", "h", "-", "x"}]}], 
             "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{"c1", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", "HPulley"}], "}"}]}], "}"}], "]"}],
              ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{"c2", ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "HPulley"}], "}"}]}], "}"}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"GrayBlue", ",", 
               RowBox[{"Rectangle", "[", 
                RowBox[{
                 RowBox[{"c1", "-", 
                  RowBox[{"dim1", "/", "2"}]}], ",", 
                 RowBox[{"c1", "+", 
                  RowBox[{"dim1", "/", "2"}]}]}], "]"}], ",", 
               RowBox[{"Rectangle", "[", 
                RowBox[{
                 RowBox[{"c2", "-", 
                  RowBox[{"dim2", "/", "2"}]}], ",", 
                 RowBox[{"c2", "+", 
                  RowBox[{"dim2", "/", "2"}]}]}], "]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"White", ",", 
               RowBox[{"Text", "[", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(m\), \(1\)]\)\>\"", ",", "c1"}], 
                "]"}], ",", 
               RowBox[{"Text", "[", 
                RowBox[{
                "\"\<\!\(\*SubscriptBox[\(m\), \(2\)]\)\>\"", ",", "c2"}], 
                "]"}]}], "}"}], ",", 
             RowBox[{"ShadedLine", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", "HCeiling"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "HCeiling"}], "}"}]}], "}"}], ",", ".2"}],
               "]"}], ",", 
             RowBox[{"ShadedLine", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1.5"}], ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1.5", ",", "0"}], "}"}]}], "}"}], ",", 
               RowBox[{"-", ".2"}]}], "]"}], ",", 
             RowBox[{"Pulley", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "HPulley"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "HCeiling"}], "}"}], ",", "1", ",", 
               RowBox[{"RimLineDirectives", "\[Rule]", 
                RowBox[{"AbsoluteThickness", "[", "1.5", "]"}]}], ",", 
               RowBox[{"PulleyStyle", "\[Rule]", 
                RowBox[{"Spokes", "[", "]"}]}], ",", 
               RowBox[{"PulleyOversize", "\[Rule]", "1.01`"}], ",", 
               RowBox[{"RotationAngle", "\[Rule]", 
                RowBox[{"-", "x"}]}]}], "]"}]}], "}"}], ",", 
           RowBox[{"BaseStyle", "->", 
            RowBox[{"{", 
             RowBox[{"14", ",", 
              RowBox[{"FontFamily", "->", "\"\<Times\>\""}]}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "250"}]}], "]"}]}], "]"}]}], "]"}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       SqrtBox[
        RowBox[{"2", 
         RowBox[{"h", "/", "a"}]}]]}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.46655280317697*^9, 3.466552815417181*^9}, {
   3.46655286644704*^9, 3.4665528771383257`*^9}, {3.466552957389618*^9, 
   3.4665530024808493`*^9}, {3.466562599641433*^9, 3.466562601416074*^9}, {
   3.466562645879641*^9, 3.466562647544606*^9}, {3.466562706055457*^9, 
   3.466562772939807*^9}, {3.466562876847755*^9, 3.466562895246279*^9}, {
   3.466562932261322*^9, 3.4665629346838923`*^9}, {3.466562998607835*^9, 
   3.4665630223522243`*^9}, {3.466563052575246*^9, 3.466563061930079*^9}, {
   3.466564591015324*^9, 3.46656459138074*^9}, {3.466590202720212*^9, 
   3.46659026092784*^9}, {3.4666124297150593`*^9, 3.46661245052065*^9}, 
   3.4666128462994843`*^9, {3.623875044343631*^9, 3.623875050429008*^9}, {
   3.623875130878806*^9, 3.623875163451664*^9}, {3.6238764499863*^9, 
   3.623876634811475*^9}, {3.62387666719007*^9, 3.623876744487167*^9}, {
   3.6238859885710697`*^9, 3.623886038523596*^9}, {3.6238860921930027`*^9, 
   3.623886123248168*^9}, {3.62388620975323*^9, 3.6238862267335987`*^9}, {
   3.6238862628494864`*^9, 3.6238863113595667`*^9}, {3.6238864610479116`*^9, 
   3.623886466383359*^9}, {3.623886505918284*^9, 3.623886518454568*^9}, {
   3.6238865821991577`*^9, 3.623886662952697*^9}, {3.623886693235523*^9, 
   3.623886697010919*^9}, {3.623886736969615*^9, 3.623886857263193*^9}, 
   3.623886899896637*^9, {3.62388693681153*^9, 3.6238869442522993`*^9}, {
   3.623886981711617*^9, 3.623886982917313*^9}, {3.623887034437608*^9, 
   3.623887306543879*^9}, {3.623887340768618*^9, 3.623887349925583*^9}, {
   3.6238874764218597`*^9, 3.6238874906614923`*^9}, 3.623887546850028*^9, {
   3.623887614677225*^9, 3.623887643135894*^9}, 3.6238876731949463`*^9, {
   3.623887827547708*^9, 3.6238878992292147`*^9}, {3.623887953711955*^9, 
   3.6238879871325893`*^9}, {3.623888034518588*^9, 3.6238881233731947`*^9}, {
   3.6238882079837008`*^9, 3.6238882734935827`*^9}, {3.623888330592031*^9, 
   3.6238884259729843`*^9}, {3.623888622151168*^9, 3.623888661027253*^9}, {
   3.6238886978159513`*^9, 3.6238887264304*^9}, {3.664452411461194*^9, 
   3.6644524680928802`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = 3.5182546159988535`, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`t$$], 0, 5.477225575051661}}, Typeset`size$$ = {
    313., {320., 331.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`t$45172$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`t$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$45172$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      With[{$CellContext`x$ = 0.5 0.2 $CellContext`t$$^2}, 
        With[{$CellContext`c1$ = {-1, 
            0.5 Part[{0.4, 0.5}, 2] + $CellContext`x$}, $CellContext`c2$ = {
           1, 0.5 Part[{0.4, 0.5}, 2] + 3 - $CellContext`x$}}, 
         Graphics[{
           Line[{$CellContext`c1$, {-1, 4.5}}], 
           Line[{$CellContext`c2$, {1, 4.5}}], {$CellContext`GrayBlue, 
            
            Rectangle[$CellContext`c1$ - {0.4, 0.5}/
             2, $CellContext`c1$ + {0.4, 0.5}/2], 
            
            Rectangle[$CellContext`c2$ - {0.5, 0.6}/
             2, $CellContext`c2$ + {0.5, 0.6}/2]}, {White, 
            Text["\!\(\*SubscriptBox[\(m\), \(1\)]\)", $CellContext`c1$], 
            Text["\!\(\*SubscriptBox[\(m\), \(2\)]\)", $CellContext`c2$]}, 
           $CellContext`ShadedLine[{{-1, 6}, {1, 6}}, 0.2], 
           $CellContext`ShadedLine[{{-1.5, 0}, {1.5, 0}}, -0.2], 
           $CellContext`Pulley[{0, 4.5}, {0, 6}, 
            1, $CellContext`RimLineDirectives -> 
            AbsoluteThickness[
             1.5], $CellContext`PulleyStyle -> $CellContext`Spokes[], \
$CellContext`PulleyOversize -> 
            1.01, $CellContext`RotationAngle -> -$CellContext`x$]}, 
          BaseStyle -> {14, FontFamily -> "Times"}, ImageSize -> 250]]], 
      "Specifications" :> {{$CellContext`t$$, 0, 5.477225575051661, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{404., {368., 375.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.664452688642371*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SimpleTruck and AngleLabel (with Code)", "Subsection",
 CellChangeTimes->{
  3.3824524252213373`*^9, {3.514308595622859*^9, 3.514308595844242*^9}, 
   3.514662627149618*^9, 3.514662723834064*^9, {3.614640343117742*^9, 
   3.614640359900044*^9}, {3.61464040823173*^9, 3.614640416397993*^9}, {
   3.614641145707143*^9, 3.61464114570934*^9}, 3.623063900825736*^9, 
   3.623158157165463*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Theta]", "=", 
      RowBox[{"35", "\[Degree]"}]}], ",", 
     RowBox[{"L", "=", "5"}], ",", 
     RowBox[{"R", "=", ".5"}], ",", 
     RowBox[{"a", "=", "6"}], ",", 
     RowBox[{"b", "=", "8"}], ",", "\[IndentingNewLine]", 
     RowBox[{"P0", "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"A", "=", 
      RowBox[{"{", 
       RowBox[{"5", ",", "0"}], "}"}]}], ",", 
     RowBox[{"ACenter", "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.5"}], "}"}]}], ",", 
     RowBox[{"T", "=", "7"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"P5", "=", 
       RowBox[{"-", 
        RowBox[{"Polar", "[", 
         RowBox[{"5", ",", 
          RowBox[{
           RowBox[{"90", "\[Degree]"}], "-", "\[Theta]"}]}], "]"}]}]}], "}"}],
      ",", "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"AbsoluteThickness", "[", "2.", "]"}], ",", 
           RowBox[{"Arrowheads", "[", ".06", "]"}], ",", 
           RowBox[{"LabeledArrow", "[", 
            RowBox[{
             RowBox[{"ACenter", "-", 
              RowBox[{"A", "/", "2"}]}], ",", 
             RowBox[{"ACenter", "+", 
              RowBox[{"A", "/", "2"}]}], ",", "\"\<\!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\>\"", ",", 
             RowBox[{"TextOffset", "\[Rule]", ".75"}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"AbsoluteDashing", "[", "3", "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{"P0", ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "3"}]}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{"P0", ",", "P5"}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"AngleLabel", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", "90"}], "\[Degree]"}], "-", "\[Theta]"}], ",", 
             RowBox[{
              RowBox[{"-", "90"}], "\[Degree]"}]}], "}"}], ",", "2", ",", "3",
            ",", "\"\<\[Theta]\>\""}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"RGBColor", "[", 
            RowBox[{".4", ",", ".4", ",", ".6"}], "]"}], ",", 
           RowBox[{"Disk", "[", 
            RowBox[{"P5", ",", "R"}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"RoundedBox", "[", 
           RowBox[{"P5", ",", "P5", ",", "1.2"}], "]"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"SimpleTruck", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{
              RowBox[{"-", "0.8"}], "\[Times]", "2", "a"}]}], "}"}], ",", 
           RowBox[{"Scale", "\[Rule]", 
            RowBox[{"2", "a"}]}]}], "]"}]}], "}"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"12", ",", 
          RowBox[{"FontFamily", "->", "\"\<Times\>\""}]}], "}"}]}]}], "]"}]}],
     "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.43847690593223*^9, 3.438476911519658*^9}, {
   3.438476971509345*^9, 3.438476989307042*^9}, {3.438477021447085*^9, 
   3.438477050869197*^9}, {3.438477088817416*^9, 3.438477092831294*^9}, {
   3.43847712530332*^9, 3.438477254991366*^9}, {3.438477292865099*^9, 
   3.43847733339762*^9}, {3.4384773673597593`*^9, 3.4384776053181667`*^9}, {
   3.438477685120661*^9, 3.438477686789332*^9}, {3.438477749126143*^9, 
   3.438477867332876*^9}, {3.438477930301591*^9, 3.4384779702807693`*^9}, {
   3.438478003820188*^9, 3.438478116272838*^9}, {3.438478164959565*^9, 
   3.438478165581017*^9}, {3.438478204560442*^9, 3.438478211308383*^9}, {
   3.438478256916995*^9, 3.4384782731686172`*^9}, {3.438478372496592*^9, 
   3.4384784188542213`*^9}, {3.438538167229072*^9, 3.438538233224402*^9}, {
   3.438538693396399*^9, 3.438538731927128*^9}, {3.43853877382018*^9, 
   3.438538786112422*^9}, 3.43853883889454*^9, 3.438560818457644*^9, {
   3.438600028393051*^9, 3.438600044705346*^9}, {3.438601594084465*^9, 
   3.438601599273881*^9}, {3.438691573726619*^9, 3.43869164843326*^9}, 
   3.43869558205912*^9, {3.609119866197475*^9, 3.609120081332878*^9}, 
   3.609120141398336*^9, 3.609120207620131*^9, {3.609154652882593*^9, 
   3.609154711736229*^9}, 3.609203278133665*^9, {3.609203315517741*^9, 
   3.6092033234234858`*^9}, {3.609203623941305*^9, 3.609203667927806*^9}, {
   3.6094535170184937`*^9, 3.6094535357297153`*^9}, {3.609453597528077*^9, 
   3.609453599069166*^9}, {3.609453678473893*^9, 3.6094537138548107`*^9}, {
   3.609454022673789*^9, 3.609454072588316*^9}, 3.609454104629883*^9, {
   3.609454136276925*^9, 3.609454141352181*^9}, {3.614639076432938*^9, 
   3.614639217948243*^9}, {3.622972117432878*^9, 3.6229721358928757`*^9}, {
   3.622972200615193*^9, 3.622972244253727*^9}, {3.6229992323835382`*^9, 
   3.622999238189617*^9}, {3.622999401394081*^9, 3.622999421922612*^9}, {
   3.623073440249449*^9, 3.623073440710495*^9}, {3.62307389343039*^9, 
   3.623073898123784*^9}, {3.623891067283766*^9, 3.623891079266756*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {AbsoluteThickness[2.], Arrowheads[0.06], 
    InsetBox["\<\"\\!\\(\\*\\nStyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\"\>", Offset[{0., 11.25}, {0., 1.5}]], 
    ArrowBox[NCache[{{Rational[-5, 2], 1.5}, {Rational[5, 2], 1.5}}, {{-2.5, 
      1.5}, {2.5, 1.5}}]]}, 
   {AbsoluteDashing[3], LineBox[{{0, 0}, {0, -3}}]}, 
   LineBox[NCache[{{0, 0}, {(-5) Sin[35 Degree], (-5) Cos[35 Degree]}}, {{0, 
      0}, {-2.8678821817552302`, -4.095760221444959}}]], {
    CircleBox[{0, 0}, 2, 
     NCache[{(-125) Degree, (-90) 
       Degree}, {-2.181661564992912, -1.5707963267948966`}]], 
    InsetBox["\<\"\[Theta]\"\>", 
     NCache[{(-3) Sin[Rational[35, 2] Degree], (-3) 
       Cos[Rational[35, 2] 
         Degree]}, {-0.9021173985128194, -2.861150852244681}]]}, 
   {RGBColor[0.4, 0.4, 0.6], 
    DiskBox[NCache[{(-5) Sin[35 Degree], (-5) 
       Cos[35 Degree]}, {-2.8678821817552302`, -4.095760221444959}], 0.5]}, 
   {Opacity[0], EdgeForm[{RGBColor[1, 0, 0], AbsoluteDashing[2.5]}], 
    RectangleBox[{-4.06788218175523, -5.295760221444959}, {-1.6678821817552303`, -2.8957602214449585`},
     
     RoundingRadius->1.2]}, 
   {GrayLevel[0.7], 
    PolygonBox[{{6.18, -8.760000000000002}, {6.18, -1.2000000000000028`}, {
     9.6, -1.2000000000000028`}, {9.662717077960592, -1.2032868627790378`}, {
     9.724747014490655, -1.213111439559718}, {
     9.78541019662497, -1.2293660902229107`}, {
     9.844041985845479, -1.251872725414442}, {
     9.899999999999999, -1.2803847577293404`}, {
     9.952671151375483, -1.314589803375032}, {
     10.001478363815314`, -1.3541131047135657`}, {
     10.045886895286436`, -1.3985216361846877`}, {
     10.085410196624968`, -1.4473288486245188`}, {
     10.119615242270664`, -1.5000000000000018`}, {
     12.519615242270664`, -5.656921938165308}}], 
    PolygonBox[{{6.18, -8.760000000000002}, {15., -8.760000000000002}, {
     15., -6.000000000000001}, {14.988321682489884`, -5.832992278847923}, {
     14.953514035125984`, -5.669235173019603}, {
     14.896254549171122`, -5.511916028309041}, {
     14.81765771538771, -5.364096882920156}, {
     14.719253331742774`, -5.228654868376154}, {
     14.60295672763063, -5.108226209427128}, {
     14.471031484164897`, -5.005154912933952}, {
     14.326045376146894`, -4.921447144441001}, {
     14.170820393249937`, -4.858732180445816}, {
     14.008377813200317`, -4.818230696385351}, {
     9.28130059874172, -3.984719443584085}}], 
    {GrayLevel[0.4], AbsoluteThickness[2], 
     {GrayLevel[0.7], 
      PolygonBox[{{-6., -4.200000000000002}, {-6., -8.400000000000002}, {
       6., -8.400000000000002}, {
       6., -1.7763568394002505`*^-15}, {-6., -1.7763568394002505`*^-15}, \
{-6., -4.200000000000002}, {-6.36, -4.200000000000002}, {-6.36, 
       0.35999999999999815`}, {6.36, 0.35999999999999815`}, {
       6.36, -8.760000000000002}, {-6.36, -8.760000000000002}, {-6.36, \
-4.200000000000002}}]}, 
     LineBox[{{-6., -4.200000000000002}, {-6., -1.7763568394002505`*^-15}, {
      6., -1.7763568394002505`*^-15}, {
      6., -8.400000000000002}, {-6., -8.400000000000002}, {-6., \
-4.200000000000002}}]}, 
    {GrayLevel[0.4], DiskBox[{-4.199999999999999, -8.64}, 0.96], 
     DiskBox[{13.200000000000001`, -8.64}, 0.96]}}},
  BaseStyle->{12, FontFamily -> "Times"}]], "Output",
 CellChangeTimes->{3.664452491608705*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "AngleLabel"}]], "Input",
 CellChangeTimes->{{3.623074765525793*^9, 3.62307477043501*^9}}],

Cell[BoxData[
 StyleBox["\<\"AngleLabel[base:{0,0},{ang1,ang2},r,rtext,str,opts] or \
AngleLabel[base:{0,0},{vector1,vector2},r,rtext,str,opts].  The option \
ArrowSize\[Rule]0 draws no arrow. Negative ArrowSize changes its direction to \
clockwise.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.66445250527465*^9},
 CellTags->"Info-78183e64-64c1-4ad0-b98d-28ac50481b71"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SimpleTruck"}]], "Input",
 CellChangeTimes->{{3.622972284551219*^9, 3.622972292462468*^9}}],

Cell[BoxData[
 StyleBox["\<\"SimpleTruck[r:{0,0},opts] makes a truck with r below the \
center of the open back at road level. Scale is an option with default value \
1. The open back interior as width 1\[Times]Scale with floor and ceiling at \
y=0.1\[Times]Scale and y=.8\[Times]Scale. The cab has an additional width \
0.75\[Times]Scale.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.664452508320325*^9},
 CellTags->"Info-415fab57-c6fc-4d83-8920-f0f6afc8ea83"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", "=", "5"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"SimpleTruck", "[", 
        RowBox[{"Scale", "\[Rule]", "a"}], "]"}], ",", 
       RowBox[{"AbsolutePointSize", "[", "5", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{".1", " ", "a"}]}], "}"}], "]"}], ",", 
         RowBox[{"Text", "[", " ", 
          RowBox[{"\"\<(0, 0.1\[VeryThinSpace]a)\>\"", ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{".1", "a"}]}], "}"}], "+", 
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{".075", " ", "a"}]}], "}"}]}]}], "]"}]}], "}"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Point", "[", 
            RowBox[{
            "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "]"}], ",", 
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{
             "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
             RowBox[{
              RowBox[{
              "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
              "+", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{
                 RowBox[{"-", ".075"}], " ", "a"}]}], "}"}]}]}], "]"}]}], 
          "}"}], "&"}], "/@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "\"\<(0, 0)\>\""}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"-", ".5"}], " ", "a"}], ",", "0"}], "}"}], ",", 
            "\"\<(-0.5\[VeryThinSpace]a, 0)\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{".5", " ", "a"}], ",", "0"}], "}"}], ",", 
            "\"\<(0.5\[VeryThinSpace]a, 0)\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{".8", " ", "a"}]}], "}"}], ",", 
            "\"\<(0, 0.8\[VeryThinSpace]a)\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"1.25", "\[VeryThinSpace] ", "a"}], ",", "0"}], "}"}], 
            ",", "\"\<(1.25\[VeryThinSpace]a, 0)\>\""}], "}"}]}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<SimpleTruck[Scale\[Rule]a]\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{".45", " ", "a"}]}], "}"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"12", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "}"}]}]}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.43847690593223*^9, 3.438476911519658*^9}, {
   3.438476971509345*^9, 3.438476989307042*^9}, {3.438477021447085*^9, 
   3.438477050869197*^9}, {3.438477088817416*^9, 3.438477092831294*^9}, {
   3.43847712530332*^9, 3.438477254991366*^9}, {3.438477292865099*^9, 
   3.43847733339762*^9}, {3.4384773673597593`*^9, 3.4384776053181667`*^9}, {
   3.438477685120661*^9, 3.438477686789332*^9}, {3.438477749126143*^9, 
   3.438477867332876*^9}, {3.438477930301591*^9, 3.4384779702807693`*^9}, {
   3.438478003820188*^9, 3.438478116272838*^9}, {3.438478164959565*^9, 
   3.438478165581017*^9}, {3.438478204560442*^9, 3.438478211308383*^9}, {
   3.438478256916995*^9, 3.4384782731686172`*^9}, {3.438478372496592*^9, 
   3.4384784188542213`*^9}, {3.438538167229072*^9, 3.438538233224402*^9}, {
   3.438538693396399*^9, 3.438538731927128*^9}, {3.43853877382018*^9, 
   3.438538786112422*^9}, 3.43853883889454*^9, 3.438560818457644*^9, {
   3.438600028393051*^9, 3.438600044705346*^9}, {3.438601594084465*^9, 
   3.438601599273881*^9}, {3.438691573726619*^9, 3.43869164843326*^9}, 
   3.43869558205912*^9, {3.609119866197475*^9, 3.609120081332878*^9}, 
   3.609120141398336*^9, 3.609120207620131*^9, {3.609154652882593*^9, 
   3.609154711736229*^9}, 3.609203278133665*^9, {3.609203315517741*^9, 
   3.6092033234234858`*^9}, {3.609203623941305*^9, 3.609203667927806*^9}, {
   3.6094535170184937`*^9, 3.6094535357297153`*^9}, {3.609453597528077*^9, 
   3.609453599069166*^9}, {3.609453678473893*^9, 3.6094537138548107`*^9}, {
   3.609454022673789*^9, 3.609454072588316*^9}, 3.609454104629883*^9, {
   3.609454136276925*^9, 3.609454141352181*^9}, {3.614639076432938*^9, 
   3.614639217948243*^9}, {3.622972117432878*^9, 3.6229721358928757`*^9}, {
   3.622972200615193*^9, 3.622972244253727*^9}, {3.6229992323835382`*^9, 
   3.622999238189617*^9}, 3.622999274483498*^9, {3.6229993415446177`*^9, 
   3.622999367269071*^9}, {3.622999439918767*^9, 3.622999487617683*^9}, {
   3.6229995244347553`*^9, 3.6229996753386793`*^9}, {3.622999733369862*^9, 
   3.622999843280229*^9}, {3.622999938706595*^9, 3.623000112758651*^9}, {
   3.62300015148849*^9, 3.623000235358212*^9}, {3.623000452797488*^9, 
   3.62300051105641*^9}, {3.623000730949998*^9, 3.623000769891837*^9}, {
   3.623000809806693*^9, 3.623000893266425*^9}, {3.6230734511441193`*^9, 
   3.623073605643094*^9}, {3.623073859351653*^9, 3.623073877470269*^9}, {
   3.623114313946107*^9, 3.6231143208240557`*^9}, {3.6231489537569027`*^9, 
   3.623149050704582*^9}, {3.6238911311028023`*^9, 3.6238911365400867`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.7], 
    PolygonBox[{{2.575, 0.35000000000000003`}, {2.575, 3.5}, {
     3.9999999999999996`, 3.5}, {4.026132115816913, 3.498630473842068}, {
     4.05197792270444, 3.4945369001834514`}, {4.077254248593737, 
     3.4877641290737884`}, {4.10168416076895, 3.47838636441065}, {4.125, 
     3.4665063509461094`}, {4.146946313073118, 3.4522542485937366`}, {
     4.167282651589714, 3.4357862063693485`}, {4.1857862063693485`, 
     3.4172826515897143`}, {4.202254248593737, 3.3969463130731183`}, {
     4.21650635094611, 3.3749999999999996`}, {5.21650635094611, 
     1.6429491924311224`}}], 
    PolygonBox[{{2.575, 0.35000000000000003`}, {6.25, 0.35000000000000003`}, {
     6.25, 1.5000000000000002`}, {6.2451340343707855`, 1.5695865504800328`}, {
     6.2306308479691594`, 1.6378186779084998`}, {6.2067727288213, 
     1.7033683215379003`}, {6.174024048078213, 1.7649596321166026`}, {
     6.1330222215594885`, 1.8213938048432698`}, {6.084565303179429, 
     1.8715724127386975`}, {6.029596451735374, 1.914518786277521}, {
     5.9691855733945385`, 1.9493970231495836`}, {5.904508497187474, 
     1.9755282581475768`}, {5.836824088833465, 1.992403876506104}, {
     3.867208582809049, 2.3397002318399647`}}], 
    {GrayLevel[0.4], AbsoluteThickness[2], 
     {GrayLevel[0.7], 
      PolygonBox[{{-2.5, 2.25}, {-2.5, 0.5}, {2.5, 0.5}, {2.5, 
       3.9999999999999996`}, {-2.5, 3.9999999999999996`}, {-2.5, 
       2.25}, {-2.65, 2.25}, {-2.65, 4.1499999999999995`}, {2.65, 
       4.1499999999999995`}, {2.65, 0.35000000000000003`}, {-2.65, 
       0.35000000000000003`}, {-2.65, 2.25}}]}, 
     LineBox[{{-2.5, 2.25}, {-2.5, 3.9999999999999996`}, {2.5, 
      3.9999999999999996`}, {2.5, 0.5}, {-2.5, 0.5}, {-2.5, 2.25}}]}, 
    {GrayLevel[0.4], DiskBox[{-1.75, 0.4}, 0.4], DiskBox[{5.5, 0.4}, 0.4]}}, 
   {AbsolutePointSize[
    5], {PointBox[{0, 0.5}], 
     InsetBox["\<\"(0, 0.1\[VeryThinSpace]a)\"\>", {0, 0.875}]}, {{
      PointBox[{0, 0}], InsetBox["\<\"(0, 0)\"\>", {0, -0.375}]}, {
      PointBox[{-2.5, 0}], 
      InsetBox["\<\"(-0.5\[VeryThinSpace]a, 0)\"\>", {-2.5, -0.375}]}, {
      PointBox[{2.5, 0}], 
      InsetBox["\<\"(0.5\[VeryThinSpace]a, 0)\"\>", {2.5, -0.375}]}, {
      PointBox[{0, 4.}], 
      InsetBox["\<\"(0, 0.8\[VeryThinSpace]a)\"\>", {0, 3.625}]}, {
      PointBox[{6.25, 0}], 
      InsetBox["\<\"(1.25\[VeryThinSpace]a, 0)\"\>", {6.25, -0.375}]}}, 
    InsetBox["\<\"SimpleTruck[Scale\[Rule]a]\"\>", {0, 2.25}]}},
  BaseStyle->{12, FontFamily -> "Times"}]], "Output",
 CellChangeTimes->{3.664452511123006*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", "=", "5"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"SimpleTruck", "[", 
       RowBox[{
        RowBox[{"Scale", "\[Rule]", "a"}], ",", 
        RowBox[{"FilledBack", "\[Rule]", "True"}]}], "]"}], "}"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"12", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "}"}]}]}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.43847690593223*^9, 3.438476911519658*^9}, {
   3.438476971509345*^9, 3.438476989307042*^9}, {3.438477021447085*^9, 
   3.438477050869197*^9}, {3.438477088817416*^9, 3.438477092831294*^9}, {
   3.43847712530332*^9, 3.438477254991366*^9}, {3.438477292865099*^9, 
   3.43847733339762*^9}, {3.4384773673597593`*^9, 3.4384776053181667`*^9}, {
   3.438477685120661*^9, 3.438477686789332*^9}, {3.438477749126143*^9, 
   3.438477867332876*^9}, {3.438477930301591*^9, 3.4384779702807693`*^9}, {
   3.438478003820188*^9, 3.438478116272838*^9}, {3.438478164959565*^9, 
   3.438478165581017*^9}, {3.438478204560442*^9, 3.438478211308383*^9}, {
   3.438478256916995*^9, 3.4384782731686172`*^9}, {3.438478372496592*^9, 
   3.4384784188542213`*^9}, {3.438538167229072*^9, 3.438538233224402*^9}, {
   3.438538693396399*^9, 3.438538731927128*^9}, {3.43853877382018*^9, 
   3.438538786112422*^9}, 3.43853883889454*^9, 3.438560818457644*^9, {
   3.438600028393051*^9, 3.438600044705346*^9}, {3.438601594084465*^9, 
   3.438601599273881*^9}, {3.438691573726619*^9, 3.43869164843326*^9}, 
   3.43869558205912*^9, {3.609119866197475*^9, 3.609120081332878*^9}, 
   3.609120141398336*^9, 3.609120207620131*^9, {3.609154652882593*^9, 
   3.609154711736229*^9}, 3.609203278133665*^9, {3.609203315517741*^9, 
   3.6092033234234858`*^9}, {3.609203623941305*^9, 3.609203667927806*^9}, {
   3.6094535170184937`*^9, 3.6094535357297153`*^9}, {3.609453597528077*^9, 
   3.609453599069166*^9}, {3.609453678473893*^9, 3.6094537138548107`*^9}, {
   3.609454022673789*^9, 3.609454072588316*^9}, 3.609454104629883*^9, {
   3.609454136276925*^9, 3.609454141352181*^9}, {3.614639076432938*^9, 
   3.614639217948243*^9}, {3.622972117432878*^9, 3.6229721358928757`*^9}, {
   3.622972200615193*^9, 3.622972244253727*^9}, {3.6229992323835382`*^9, 
   3.622999238189617*^9}, 3.622999274483498*^9, {3.6229993415446177`*^9, 
   3.622999367269071*^9}, {3.622999439918767*^9, 3.622999487617683*^9}, {
   3.6229995244347553`*^9, 3.6229996753386793`*^9}, {3.622999733369862*^9, 
   3.622999843280229*^9}, {3.622999938706595*^9, 3.623000112758651*^9}, {
   3.62300015148849*^9, 3.623000235358212*^9}, {3.623000452797488*^9, 
   3.62300051105641*^9}, {3.623000730949998*^9, 3.623000769891837*^9}, {
   3.623000809806693*^9, 3.623000893266425*^9}, {3.6230734511441193`*^9, 
   3.623073605643094*^9}, {3.623073859351653*^9, 3.623073877470269*^9}, {
   3.623114313946107*^9, 3.6231143208240557`*^9}, {3.6231489537569027`*^9, 
   3.623149050704582*^9}, {3.6238911311028023`*^9, 3.6238911365400867`*^9}, {
   3.6239413592344723`*^9, 3.623941405793796*^9}, {3.623941528994094*^9, 
   3.623941540749022*^9}, {3.6239415967730703`*^9, 3.623941600441804*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0.7], 
   PolygonBox[{{2.575, 0.35000000000000003`}, {2.575, 3.5}, {
    3.9999999999999996`, 3.5}, {4.026132115816913, 3.498630473842068}, {
    4.05197792270444, 3.4945369001834514`}, {4.077254248593737, 
    3.4877641290737884`}, {4.10168416076895, 3.47838636441065}, {4.125, 
    3.4665063509461094`}, {4.146946313073118, 3.4522542485937366`}, {
    4.167282651589714, 3.4357862063693485`}, {4.1857862063693485`, 
    3.4172826515897143`}, {4.202254248593737, 3.3969463130731183`}, {
    4.21650635094611, 3.3749999999999996`}, {5.21650635094611, 
    1.6429491924311224`}}], 
   PolygonBox[{{2.575, 0.35000000000000003`}, {6.25, 0.35000000000000003`}, {
    6.25, 1.5000000000000002`}, {6.2451340343707855`, 1.5695865504800328`}, {
    6.2306308479691594`, 1.6378186779084998`}, {6.2067727288213, 
    1.7033683215379003`}, {6.174024048078213, 1.7649596321166026`}, {
    6.1330222215594885`, 1.8213938048432698`}, {6.084565303179429, 
    1.8715724127386975`}, {6.029596451735374, 1.914518786277521}, {
    5.9691855733945385`, 1.9493970231495836`}, {5.904508497187474, 
    1.9755282581475768`}, {5.836824088833465, 1.992403876506104}, {
    3.867208582809049, 2.3397002318399647`}}], 
   {GrayLevel[0.7], RectangleBox[{2.65, 4.1499999999999995`}, {-2.65, 0.35}]}, 
   {GrayLevel[0.4], DiskBox[{-1.75, 0.4}, 0.4], DiskBox[{5.5, 0.4}, 0.4]}},
  BaseStyle->{12, FontFamily -> "Times"}]], "Output",
 CellChangeTimes->{3.664452514873063*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SimpleTruck"}]], "Input",
 CellChangeTimes->{{3.623941412983902*^9, 3.6239414186310863`*^9}}],

Cell[BoxData[
 StyleBox["\<\"SimpleTruck[r:{0,0},opts] makes a truck with r below the \
center of the open back at road level. Scale is an option with default value \
1. The open back interior as width 1\[Times]Scale with floor and ceiling at \
y=0.1\[Times]Scale and y=.8\[Times]Scale. The cab has an additional width \
0.75\[Times]Scale.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.664452519399003*^9},
 CellTags->"Info-15083792-f25b-41dc-bc66-d4d432c2d2e3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "SimpleTruck", "]"}]], "Input",
 CellChangeTimes->{{3.623941423677453*^9, 3.623941435340446*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Reverse", "\[Rule]", "False"}], ",", 
   RowBox[{"Scale", "\[Rule]", "1"}], ",", 
   RowBox[{"TireColor", "\[Rule]", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {GrayLevel[0.4], RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->GrayLevel[0.2666666666666667],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification]}],
        PlotRangePadding->None],
       "GrayLevel[0.4]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0.4]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["GrayLevelColorValueSelector"], {
            0, {Left, Bottom}}, {Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     GrayLevel[0.4],
     Editable->False,
     Selectable->False]}], ",", 
   RowBox[{"TruckColor", "\[Rule]", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {GrayLevel[0.7], RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->GrayLevel[0.4666666666666667],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification]}],
        PlotRangePadding->None],
       "GrayLevel[0.7]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0.7]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["GrayLevelColorValueSelector"], {
            0, {Left, Bottom}}, {Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     GrayLevel[0.7],
     Editable->False,
     Selectable->False]}], ",", 
   RowBox[{"FilledBack", "\[Rule]", "False"}]}], "}"}]], "Output",
 CellChangeTimes->{3.664452522286264*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SimpleCar, DoubleArrow and ShadedLine (with Code)", "Subsection",
 CellChangeTimes->{
  3.3824524252213373`*^9, {3.514308595622859*^9, 3.514308595844242*^9}, 
   3.514662627149618*^9, 3.514662723834064*^9, {3.614640343117742*^9, 
   3.614640359900044*^9}, {3.61464046603579*^9, 3.614640474370236*^9}, {
   3.6146411384115553`*^9, 3.6146411384136143`*^9}, {3.6146412150710993`*^9, 
   3.614641220872753*^9}, 3.623158152655201*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SimpleCar"}]], "Input",
 CellChangeTimes->{{3.62300308424076*^9, 3.623003087740204*^9}}],

Cell[BoxData[
 StyleBox["\<\"SimpleCar[r:{0,0},opts] makes a car with r below the center at \
road level. The car has width 1\[Times]Scale, where Scale is an option with \
default value 1.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.664452525907041*^9},
 CellTags->"Info-80b612c1-3f1f-4b26-99ae-023af0b5a187"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", "=", 
      RowBox[{"x", "\[Function]", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{
          RowBox[{"-", ".01"}], " ", 
          SuperscriptBox["x", "2"]}]}], "}"}]}]}], ",", 
     RowBox[{"xMax", "=", "50"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"R", "=", "50"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ShadedLine", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"r", "[", "x", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", 
                RowBox[{"-", "xMax"}], ",", "xMax", ",", 
                RowBox[{"2", " ", 
                 RowBox[{"xMax", "/", "50"}]}]}], "}"}]}], "]"}], ",", 
            RowBox[{"-", "2"}], ",", 
            RowBox[{"PolygonDirectives", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"GrayLevel", "[", ".85", "]"}], "}"}]}]}], "]"}], "}"}],
          ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"AbsoluteDashing", "[", "2", "]"}], ",", 
           RowBox[{"AbsoluteThickness", "[", ".75", "]"}], ",", 
           RowBox[{"Circle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "R"}]}], "}"}], ",", "R", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Arrowheads", "[", ".03", "]"}], ",", 
           RowBox[{"DoubleArrow", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "R"}]}], "}"}], ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "R"}]}], "}"}], "+", 
              RowBox[{"Polar", "[", 
               RowBox[{"R", ",", 
                RowBox[{"25", "\[Degree]"}]}], "]"}]}], ",", 
             RowBox[{"Style", "[", 
              RowBox[{"\"\<R\>\"", ",", "Italic"}], "]"}], ",", 
             RowBox[{"TextGap", "\[Rule]", ".15"}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"SimpleCar", "[", 
          RowBox[{
           RowBox[{"Scale", "\[Rule]", "10"}], ",", 
           RowBox[{"CarColor", "\[Rule]", 
            RowBox[{"GrayLevel", "[", "0.6", "]"}]}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"v", "=", "20"}], ",", 
             RowBox[{"h", "=", "8"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"LabeledArrow", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "v"}], "/", "2"}], ",", "h"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"v", "/", "2"}], ",", "h"}], "}"}], ",", 
              "\"\<\!\(\*SubscriptBox[\(v\), \(max\)]\)=?\>\"", ",", 
              RowBox[{"TextOffset", "\[Rule]", ".7"}]}], "]"}], "}"}]}], 
          "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
       RowBox[{"BaseStyle", "->", 
        RowBox[{"{", 
         RowBox[{"12", ",", 
          RowBox[{"FontFamily", "->", "\"\<Times\>\""}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.622906693394279*^9, 3.622906694160677*^9}, 
   3.623073656754414*^9, {3.623073702310134*^9, 3.623073707008738*^9}, {
   3.623073743199377*^9, 3.6230737438405647`*^9}, {3.623073789994673*^9, 
   3.623073798129106*^9}, {3.623074986309725*^9, 3.6230749869747267`*^9}, {
   3.623893046178959*^9, 3.623893140870928*^9}, {3.664452535218368*^9, 
   3.66445257705411*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {GrayLevel[0.85], 
     PolygonBox[{{50, -25.}, {48, -23.04}, {46, -21.16}, {44, -19.36}, {
       42, -17.64}, {40, -16.}, {38, -14.44}, {36, -12.96}, {34, -11.56}, {
       32, -10.24}, {30, -9.}, {28, -7.84}, {26, -6.76}, {24, -5.76}, {
       22, -4.84}, {20, -4.}, {18, -3.24}, {16, -2.56}, {14, -1.96}, {
       12, -1.44}, {10, -1.}, {8, -0.64}, {6, -0.36}, {4, -0.16}, {
       2, -0.04}, {
       0, 0.}, {-2, -0.04}, {-4, -0.16}, {-6, -0.36}, {-8, -0.64}, {-10, \
-1.}, {-12, -1.44}, {-14, -1.96}, {-16, -2.56}, {-18, -3.24}, {-20, -4.}, \
{-22, -4.84}, {-24, -5.76}, {-26, -6.76}, {-28, -7.84}, {-30, -9.}, {-32, \
-10.24}, {-34, -11.56}, {-36, -12.96}, {-38, -14.44}, {-40, -16.}, {-42, \
-17.64}, {-44, -19.36}, {-46, -21.16}, {-48, -23.04}, {-50, -25.}, \
{-48.600142835280685`, -26.428425678285013`}, {-46.615011364442495`, \
-24.482996836863585`}, {-44.6459663781775, -22.632094549774486`}, \
{-42.67882813982165, -20.861670135254222`}, {-40.713704266118654`, \
-19.17166360386965}, {-38.75070280864192, -17.562002408738724`}, \
{-36.789930710385185`, -16.032600172098476`}, {-34.83149191833257, \
-14.583355465979537`}, {-32.87548512433213, -13.214150710179231`}, \
{-30.922001117330275`, -11.924851265558006`}, {-28.971119746142794`, \
-10.715304815421769`}, {-27.022906514227778`, -9.585341140911058}, \
{-25.077408856793262`, -8.53477240589642}, {-23.13465218577331, \
-7.563394070386444}, {-21.194635828556947`, -6.670986546066917}, \
{-19.25732902944032, -5.8573176904379345`}, {-17.322667224778257`, \
-5.122146204666351}, {-15.390548838509176`, -4.465225953334863}, \
{-13.460832867805202`, -3.8863111621236706`}, {-11.533337532322866`, \
-3.3851623748982638`}, {-9.607840238841327, -2.961552970332325}, \
{-7.684079061935202, -2.6152759584892222`}, {-5.761755860147094, \
-2.346150710238888}, {-3.840541039868329, -2.1540292282110105`}, \
{-1.9200798547271714`, -2.0388015571025417`}, {0., -2.000399960007998}, {
       1.9200798547271714`, -2.0388015571025417`}, {
       3.840541039868329, -2.1540292282110105`}, {
       5.761755860147094, -2.346150710238888}, {
       7.684079061935202, -2.6152759584892222`}, {
       9.607840238841327, -2.961552970332325}, {
       11.533337532322866`, -3.3851623748982638`}, {
       13.460832867805202`, -3.8863111621236706`}, {
       15.390548838509176`, -4.465225953334863}, {
       17.322667224778257`, -5.122146204666351}, {
       19.25732902944032, -5.8573176904379345`}, {
       21.194635828556947`, -6.670986546066917}, {
       23.13465218577331, -7.563394070386444}, {
       25.077408856793262`, -8.53477240589642}, {
       27.022906514227778`, -9.585341140911058}, {
       28.971119746142794`, -10.715304815421769`}, {
       30.922001117330275`, -11.924851265558006`}, {
       32.87548512433213, -13.214150710179231`}, {
       34.83149191833257, -14.583355465979537`}, {
       36.789930710385185`, -16.032600172098476`}, {
       38.75070280864192, -17.562002408738724`}, {
       40.713704266118654`, -19.17166360386965}, {
       42.67882813982165, -20.861670135254222`}, {
       44.6459663781775, -22.632094549774486`}, {
       46.615011364442495`, -24.482996836863585`}, {
       48.600142835280685`, -26.428425678285013`}}]}, 
    LineBox[{{-50, -25.}, {-48, -23.04}, {-46, -21.16}, {-44, -19.36}, {-42, \
-17.64}, {-40, -16.}, {-38, -14.44}, {-36, -12.96}, {-34, -11.56}, {-32, \
-10.24}, {-30, -9.}, {-28, -7.84}, {-26, -6.76}, {-24, -5.76}, {-22, -4.84}, \
{-20, -4.}, {-18, -3.24}, {-16, -2.56}, {-14, -1.96}, {-12, -1.44}, {-10, \
-1.}, {-8, -0.64}, {-6, -0.36}, {-4, -0.16}, {-2, -0.04}, {0, 0.}, {
      2, -0.04}, {4, -0.16}, {6, -0.36}, {8, -0.64}, {10, -1.}, {12, -1.44}, {
      14, -1.96}, {16, -2.56}, {18, -3.24}, {20, -4.}, {22, -4.84}, {
      24, -5.76}, {26, -6.76}, {28, -7.84}, {30, -9.}, {32, -10.24}, {
      34, -11.56}, {36, -12.96}, {38, -14.44}, {40, -16.}, {42, -17.64}, {
      44, -19.36}, {46, -21.16}, {48, -23.04}, {50, -25.}}]}, 
   {AbsoluteThickness[0.75], AbsoluteDashing[2], 
    CircleBox[{0, -50}, 50, NCache[{0, Pi}, {0, 3.141592653589793}]]}, 
   {Arrowheads[0.03], 
    ArrowBox[{{19.25904047452881, -41.019361938010135`}, {0, -50}}], 
    ArrowBox[NCache[{{26.056348877303684`, -37.849724974954896`}, {
       50 Cos[25 Degree], -50 + 50 Sin[25 Degree]}}, {{
      26.056348877303684`, -37.849724974954896`}, {
      45.31538935183249, -28.869086912965027`}}]], InsetBox[
     StyleBox["\<\"R\"\>",
      StripOnInput->False,
      FontSlant->Italic], {22.657694675916247`, -39.434543456482515`}]}, {
    {GrayLevel[0.6], 
     DiskBox[{-0.6, 0.6}, {4.4, 4.}, 
      NCache[{72 Degree, Pi}, {1.2566370614359172`, 3.141592653589793}]], 
     DiskBox[{1.9, 0.6}, {3.1, 2.5}, 
      NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], 
     PolygonBox[{{-5., 0.6}, {5., 0.6}, {1.9, 3.1}, {0.7596747752497688, 
      4.404226065180614}}]}, 
    {GrayLevel[0.4], DiskBox[{-3.5, 0.8}, 0.8], DiskBox[{3.5, 0.8}, 0.8]}}, {
    InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(max\\)]\\)=?\"\>", 
     Offset[{0., 10.5}, {0., 8.}]], ArrowBox[{{-10, 8}, {10, 8}}]}},
  BaseStyle->{12, FontFamily -> "Times"},
  ImageSize->300]], "Output",
 CellChangeTimes->{
  3.6644525286736727`*^9, {3.6644525619657297`*^9, 3.664452577654224*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PolygonBelowLine"}]], "Input",
 CellChangeTimes->{{3.623893377142232*^9, 3.623893384239438*^9}}],

Cell[BoxData[
 StyleBox["\<\"PolygonBelowLine[y0:0,expr] replaces any Line in expr with a \
Polygon between it and y=y0\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.664452584966914*^9},
 CellTags->"Info-b135235a-e966-4b91-aad0-8098d53dc990"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DoubleArrow"}]], "Input",
 CellChangeTimes->{{3.623003216046402*^9, 3.623003221618312*^9}}],

Cell[BoxData[
 StyleBox["\<\"DoubleArrow[r1,r2,text,opts] draws a double arrow between r1 \
and r2 with text at center. The text is at the center of the gap. TextGap \
option must be adjusted to give room for the Text. TextGap->0 and TextOffset \
place the text away from the center. TextGap greater than one gives inward \
pointing arrows; this is useful for small gaps.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.664452587935774*^9},
 CellTags->"Info-41a52591-3594-4d9c-8a30-d9f54aedff00"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spring and ShadedLine Example (with Code)", "Subsection",
 CellChangeTimes->{
  3.3824524252213373`*^9, {3.514308595622859*^9, 3.514308595844242*^9}, 
   3.514662627149618*^9, 3.514662723834064*^9, {3.614640343117742*^9, 
   3.614640359900044*^9}, {3.61464046603579*^9, 3.614640474370236*^9}, {
   3.614640548453722*^9, 3.6146405492848988`*^9}, {3.614641131517108*^9, 
   3.614641131519636*^9}, {3.6231492219805813`*^9, 3.623149242988648*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d0", "=", "7"}], ",", 
     RowBox[{"R", "=", ".5"}], ",", 
     RowBox[{"h", "=", "1.3"}]}], "}"}], ",", 
   RowBox[{"Manipulate", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ShadedLine", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"12", ",", 
               RowBox[{"-", ".65"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", ".65"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"R", "+", ".4"}]}], "}"}]}], "}"}], ",", ".2"}], "]"}],
          ",", 
         RowBox[{"Spring", "[", 
          RowBox[{"R", ",", "40", ",", 
           RowBox[{"d0", "+", "x"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "\"\<x\>\""}], "}"}], ",", 
       RowBox[{"-", "4.5"}], ",", "4.5"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.623018278039791*^9, 3.6230182956427097`*^9}, {
   3.623018352613172*^9, 3.623018353341663*^9}, {3.6230183907910967`*^9, 
   3.623018401601418*^9}, {3.623018498348261*^9, 3.62301852980171*^9}, {
   3.623018580825264*^9, 3.6230187427131653`*^9}, {3.6230187888695602`*^9, 
   3.623018833314455*^9}, {3.6230188667962847`*^9, 3.623018891210226*^9}, {
   3.623075273367888*^9, 3.62307529802745*^9}, {3.623113249088443*^9, 
   3.6231132654595003`*^9}, 3.623157084806026*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`x$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`x$$], 0, "x"}, -4.5, 4.5}}, Typeset`size$$ = {
    625., {52., 59.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`x$37155$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`x$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`x$$, $CellContext`x$37155$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics[{
         $CellContext`ShadedLine[{{12, -0.65}, {0, -0.65}, {0, 0.5 + 0.4}}, 
          0.2], 
         $CellContext`Spring[0.5, 40, 7 + $CellContext`x$$]}, ImageSize -> 
        500], "Specifications" :> {{{$CellContext`x$$, 0, "x"}, -4.5, 4.5}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{680., {103., 110.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.6644525980214357`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Spring"}]], "Input",
 CellChangeTimes->{{3.623001185904112*^9, 3.6230011874808283`*^9}}],

Cell[BoxData[
 StyleBox["\<\"Spring[R,num,L] gives a spring or radius R with num turns.  It \
is of length L from {0,0} to {L,0}.  Spring[{R,f},num,L] is the more general \
form with f being related to the viewing angle, the radius when viewed from \
the side is f R, where f has the default value of 0.2. As L gets small \
(relative to R) choose smaller f.\.10 f=0 is viewed from the side.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6644526234569273`*^9},
 CellTags->"Info-db8e6cab-ce76-4a5b-90ce-6e612184be4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ShadedLine"}]], "Input",
 CellChangeTimes->{{3.623018916186617*^9, 3.623018919555449*^9}}],

Cell[BoxData[
 StyleBox["\<\"ShadedLine[{r1,r2,r3,...},h,opts] gives a line with a polygon \
of width h to its left.  The option PolygonDirectives allows for \
customization of the polygon.  The line may be customized with directives as \
usual. A negative h puts the polygon on the right.  ClosedLine->True \
completes the line to a loop.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.664452626880176*^9},
 CellTags->"Info-803b9123-fde9-4019-8871-719cbe3bcc83"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CubicSmoothShift, PolygonBelowLine and SimpleCar", "Subsection",
 CellChangeTimes->{{3.623941254051158*^9, 3.62394128769175*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"?", "CubicSmoothShift"}], "\[IndentingNewLine]", 
 RowBox[{"?", "PolygonBelowLine"}]}], "Input",
 CellChangeTimes->{{3.623939270921925*^9, 3.6239392850381117`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"CubicSmoothShift[{x1,y1,m1:0},{x2,y2,m2:0},n:50] gives a Line \
with a cubic with derivatives m1 and m2 at the endpoints.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.664452631210828*^9},
 CellTags->"Info-5c7a5d50-86cb-4974-9d1a-27a679b079d0"],

Cell[BoxData[
 StyleBox["\<\"PolygonBelowLine[y0:0,expr] replaces any Line in expr with a \
Polygon between it and y=y0\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6644526313724537`*^9},
 CellTags->"Info-a82cc89e-ce9f-41cc-930e-9aefb6d0c4e2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x0", "=", 
      RowBox[{"-", ".15"}]}], ",", 
     RowBox[{"x3", "=", "2"}], ",", 
     RowBox[{"x4", "=", "10"}], ",", 
     RowBox[{"m2", "=", ".45"}], ",", 
     RowBox[{"x5", "=", "11"}], ",", 
     RowBox[{"y0", "=", 
      RowBox[{"-", ".2"}]}], ",", 
     RowBox[{"y2", "=", "2"}], ",", 
     RowBox[{"y3", "=", ".5"}], ",", 
     RowBox[{"wDash", "=", ".5"}], ",", 
     RowBox[{"osDash", "=", ".2"}]}], "}"}], ",", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ySpring", "=", 
        FractionBox["y3", "2"]}], ",", 
       RowBox[{"LSpring", "=", "1.5"}], ",", 
       RowBox[{"u", "=", 
        RowBox[{"Normalize", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "m2"}], "}"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"curve", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x3", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
          RowBox[{"CubicSmoothShift", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"x3", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x4", ",", "y2", ",", "m2"}], "}"}]}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x4", ",", "y2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x5", ",", 
               RowBox[{"y2", "+", 
                RowBox[{"m2", " ", 
                 RowBox[{"(", 
                  RowBox[{"x5", "-", "x4"}], ")"}]}]}]}], "}"}]}], "}"}], 
           "]"}]}], "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"GeometricTransformation", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"RGBColor", "[", 
                RowBox[{".4", ",", ".4", ",", ".6"}], "]"}], ",", 
               RowBox[{"Rectangle", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", ".3"}], ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{".3", ",", ".5"}], "}"}]}], "]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"White", ",", 
               RowBox[{"Text", "[", 
                RowBox[{"\"\<m\>\"", ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", ".24"}], "}"}]}], "]"}]}], "}"}]}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                 "u", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 ",", 
                 RowBox[{"-", 
                  RowBox[{
                  "u", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                 "u", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                 ",", 
                 RowBox[{
                 "u", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}], "}"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x4", ",", "y2"}], "}"}]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"GrayLevel", "[", ".8", "]"}], ",", 
           RowBox[{"Rectangle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x0", ",", "y0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "y3"}], "}"}]}], "]"}], ",", 
           RowBox[{"PolygonBelowLine", "[", 
            RowBox[{"y0", ",", "curve"}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", ".0025", "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "y3"}], "}"}]}], "}"}], "]"}], ",", 
           "curve"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"Translate", "[", 
           RowBox[{
            RowBox[{"Spring", "[", 
             RowBox[{".2", ",", "12", ",", "LSpring"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "ySpring"}], "}"}]}], "]"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", ".0015", "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"LSpring", ",", 
                RowBox[{"ySpring", "-", ".15"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"LSpring", ",", 
                RowBox[{"ySpring", "+", ".15"}]}], "}"}]}], "}"}], "]"}]}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"DoubleArrow", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x4", "+", "osDash", "+", 
               RowBox[{"wDash", "/", "2"}]}], ",", "y2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x4", "+", "osDash", "+", 
               RowBox[{"wDash", "/", "2"}]}], ",", "0"}], "}"}], ",", 
            "\"\<h\>\"", ",", 
            RowBox[{"TextGap", "\[Rule]", ".3"}], ",", 
            RowBox[{"ArrowDirectives", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Arrowheads", "[", ".015", "]"}], "}"}]}]}], "]"}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", ".00375", "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x4", "+", "osDash"}], ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x4", "+", "osDash", "+", "wDash"}], ",", "0"}], 
               "}"}]}], "}"}], "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x4", "+", "osDash"}], ",", "y2"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x4", "+", "osDash", "+", "wDash"}], ",", "y2"}], 
               "}"}]}], "}"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<k\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"LSpring", "/", "2"}], ",", 
              RowBox[{"ySpring", "+", ".5"}]}], "}"}]}], "]"}], "}"}]}], 
        "\[IndentingNewLine]", "}"}], ",", 
       RowBox[{"BaseStyle", "->", 
        RowBox[{"{", 
         RowBox[{"12", ",", "Italic", ",", 
          RowBox[{"FontFamily", "->", "\"\<Times\>\""}]}], "}"}]}]}], "]"}]}],
     "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.418149660819845*^9, 3.4181496934016733`*^9}, {
   3.41814994318474*^9, 3.418149950295899*^9}, {3.418152661489334*^9, 
   3.4181526939235277`*^9}, {3.418152727075488*^9, 3.418153052636058*^9}, {
   3.4181530894899063`*^9, 3.418153130727453*^9}, {3.418153202074065*^9, 
   3.418153286360054*^9}, {3.418153376435025*^9, 3.4181533984047403`*^9}, {
   3.4181534359129333`*^9, 3.418153593441408*^9}, {3.418153631828081*^9, 
   3.418153687254974*^9}, {3.418153761907482*^9, 3.418153793903325*^9}, {
   3.418153835013888*^9, 3.418153974626357*^9}, {3.418154015158737*^9, 
   3.4181540470966167`*^9}, 3.418154085269148*^9, {3.4181541352059603`*^9, 
   3.418154223070229*^9}, {3.418154336863247*^9, 3.418154352564102*^9}, {
   3.418154411104157*^9, 3.418154504217519*^9}, {3.418154541968686*^9, 
   3.418154554030405*^9}, {3.418154635786159*^9, 3.41815495927206*^9}, {
   3.418155058574604*^9, 3.418155075490284*^9}, {3.4181551976796093`*^9, 
   3.418155370643991*^9}, {3.418155405172288*^9, 3.418155418970409*^9}, 
   3.41815545629888*^9, {3.4181555005522957`*^9, 3.418155541648019*^9}, {
   3.418155596815206*^9, 3.4181556055263853`*^9}, {3.41815565176683*^9, 
   3.4181557896598063`*^9}, 3.418156860940445*^9, {3.418224157868457*^9, 
   3.418224193388474*^9}, 3.437916534531859*^9, {3.437916658246944*^9, 
   3.4379166716647577`*^9}, 3.445425295758252*^9, {3.4454253687097197`*^9, 
   3.4454254237202682`*^9}, {3.4454254550752373`*^9, 3.445425483168795*^9}, {
   3.445425514996162*^9, 3.4454256128379097`*^9}, {3.445425675669579*^9, 
   3.445425745013585*^9}, {3.4454258577406683`*^9, 3.445425929182577*^9}, {
   3.4454259700668087`*^9, 3.4454261146841917`*^9}, {3.4454261712314987`*^9, 
   3.445426173077598*^9}, {3.445426223799011*^9, 3.445426244436143*^9}, {
   3.4454262792171173`*^9, 3.445426314514647*^9}, {3.445426391056975*^9, 
   3.445426560049901*^9}, 3.481907615213306*^9, {3.481907736891903*^9, 
   3.481907746835342*^9}, 3.481907859409362*^9, {3.481907911227624*^9, 
   3.48190793187959*^9}, {3.4819080038980093`*^9, 3.48190801114303*^9}, {
   3.481908049693572*^9, 3.481908071975937*^9}, 3.481908143628673*^9, 
   3.481908185166098*^9, {3.481908231364771*^9, 3.481908240810288*^9}, {
   3.481908288297306*^9, 3.4819082888079023`*^9}, 3.481908340856855*^9, {
   3.481908396495697*^9, 3.4819084144961157`*^9}, 3.481908458295405*^9, {
   3.481908523864349*^9, 3.481908620446162*^9}, 3.4819230794796877`*^9, {
   3.481924125613041*^9, 3.481924129292522*^9}, {3.48192946265177*^9, 
   3.481929477631379*^9}, 3.481929569408452*^9, {3.4819296094855824`*^9, 
   3.481929730522575*^9}, {3.481929763606407*^9, 3.481929781226163*^9}, {
   3.481929818102438*^9, 3.481929818438311*^9}, {3.481930233264722*^9, 
   3.4819302468849287`*^9}, {3.4819303230993757`*^9, 3.48193039975463*^9}, {
   3.481930434785388*^9, 3.481930445118417*^9}, {3.481930481608041*^9, 
   3.4819304956328983`*^9}, 3.481930539763795*^9, {3.481930572362957*^9, 
   3.4819305726300697`*^9}, {3.481930697348686*^9, 3.4819308403749247`*^9}, {
   3.48193087523884*^9, 3.4819309303626947`*^9}, {3.481931155570994*^9, 
   3.481931157296804*^9}, {3.4819312430174913`*^9, 3.481931243447741*^9}, {
   3.481931284671919*^9, 3.481931303134004*^9}, {3.481931339437613*^9, 
   3.481931399220031*^9}, {3.4819317313499517`*^9, 3.481931766698719*^9}, {
   3.481931899829232*^9, 3.481931970690645*^9}, {3.481932014073093*^9, 
   3.481932032858307*^9}, {3.4819321399276752`*^9, 3.481932204099552*^9}, {
   3.48193224864187*^9, 3.481932255047494*^9}, {3.481932481800743*^9, 
   3.4819324978586206`*^9}, {3.4819325298303556`*^9, 
   3.4819326306314917`*^9}, {3.481932710325489*^9, 3.481932740514305*^9}, {
   3.481932774079668*^9, 3.4819328614368343`*^9}, {3.481932898501072*^9, 
   3.481932909975224*^9}, {3.481932973506837*^9, 3.481933105625144*^9}, {
   3.623938135756947*^9, 3.623938162823351*^9}, {3.6239382290975857`*^9, 
   3.6239383255263977`*^9}, {3.6239383622159557`*^9, 3.623938372687639*^9}, {
   3.623938410414877*^9, 3.623938422100642*^9}, {3.623938457260158*^9, 
   3.6239386138200493`*^9}, {3.623938682097192*^9, 3.623938689197818*^9}, {
   3.623938721956954*^9, 3.623938727167699*^9}, 3.623938869679822*^9, {
   3.623938908340858*^9, 3.623938909846648*^9}, {3.623939045568595*^9, 
   3.623939046454309*^9}, {3.623939148419842*^9, 3.6239392304742327`*^9}}],

Cell[BoxData[
 GraphicsBox[{GeometricTransformationBox[{
     {RGBColor[0.4, 0.4, 0.6], RectangleBox[{-0.3, 0}, {0.3, 0.5}]}, 
     {GrayLevel[1], InsetBox["\<\"m\"\>", {0, 0.24}]}}, {{{
     0.9119215051751063, -0.41036467732879783`}, {0.41036467732879783`, 
     0.9119215051751063}}, {10, 2}}], 
   {GrayLevel[0.8], 
    RectangleBox[{-0.15, -0.2}, {0, 0.5}], {
     PolygonBox[{{0, 0}, {2, 0}, {2, -0.2}, {0, -0.2}}], 
     PolygonBox[
      NCache[{{2, 0.}, {Rational[54, 25], 0.0009568000000000001}, {
        Rational[58, 25], 0.0038144}, {Rational[62, 25], 0.0085536}, {
        Rational[66, 25], 0.0151552}, {Rational[14, 5], 0.0236}, {
        Rational[74, 25], 0.0338688}, {Rational[78, 25], 0.0459424}, {
        Rational[82, 25], 0.0598016}, {Rational[86, 25], 0.0754272}, {
        Rational[18, 5], 0.09280000000000001}, {
        Rational[94, 25], 0.11190079999999998`}, {
        Rational[98, 25], 0.1327104}, {
        Rational[102, 25], 0.15520959999999998`}, {
        Rational[106, 25], 0.1793792}, {Rational[22, 5], 0.2052}, {
        Rational[114, 25], 0.23265280000000002`}, {
        Rational[118, 25], 0.26171839999999996`}, {
        Rational[122, 25], 0.2923776}, {Rational[126, 25], 0.3246112}, {
        Rational[26, 5], 0.3584}, {Rational[134, 25], 0.39372480000000004`}, {
        Rational[138, 25], 0.43056639999999996`}, {
        Rational[142, 25], 0.4689056}, {Rational[146, 25], 0.5087232}, {
        6, 0.55}, {Rational[154, 25], 0.5927167999999998}, {
        Rational[158, 25], 0.6368544}, {
        Rational[162, 25], 0.6823935999999999}, {
        Rational[166, 25], 0.7293151999999999}, {
        Rational[34, 5], 0.7776000000000001}, {
        Rational[174, 25], 0.8272288000000001}, {
        Rational[178, 25], 0.8781824}, {Rational[182, 25], 0.9304416}, {
        Rational[186, 25], 0.9839871999999998}, {Rational[38, 5], 1.0388}, {
        Rational[194, 25], 1.0948608}, {Rational[198, 25], 1.1521504}, {
        Rational[202, 25], 1.2106496}, {
        Rational[206, 25], 1.2703392000000002`}, {
        Rational[42, 5], 1.3312000000000002`}, {
        Rational[214, 25], 1.3932128}, {Rational[218, 25], 1.4563584}, {
        Rational[222, 25], 1.5206176}, {Rational[226, 25], 1.5859712}, {
        Rational[46, 5], 1.6524}, {Rational[234, 25], 1.7198848}, {
        Rational[238, 25], 1.7884064}, {Rational[242, 25], 1.8579456}, {
        Rational[246, 25], 1.9284832}, {10, 2.}, {10, -0.2}, {2, -0.2}}, {{
        2, 0.}, {2.16, 0.0009568000000000001}, {2.32, 0.0038144}, {2.48, 
        0.0085536}, {2.64, 0.0151552}, {2.8, 0.0236}, {2.96, 0.0338688}, {
        3.12, 0.0459424}, {3.28, 0.0598016}, {3.44, 0.0754272}, {3.6, 
        0.09280000000000001}, {3.76, 0.11190079999999998`}, {3.92, 
        0.1327104}, {4.08, 0.15520959999999998`}, {4.24, 0.1793792}, {4.4, 
        0.2052}, {4.56, 0.23265280000000002`}, {4.72, 0.26171839999999996`}, {
        4.88, 0.2923776}, {5.04, 0.3246112}, {5.2, 0.3584}, {5.36, 
        0.39372480000000004`}, {5.52, 0.43056639999999996`}, {5.68, 
        0.4689056}, {5.84, 0.5087232}, {6, 0.55}, {6.16, 
        0.5927167999999998}, {6.32, 0.6368544}, {6.48, 0.6823935999999999}, {
        6.64, 0.7293151999999999}, {6.8, 0.7776000000000001}, {6.96, 
        0.8272288000000001}, {7.12, 0.8781824}, {7.28, 0.9304416}, {7.44, 
        0.9839871999999998}, {7.6, 1.0388}, {7.76, 1.0948608}, {7.92, 
        1.1521504}, {8.08, 1.2106496}, {8.24, 1.2703392000000002`}, {8.4, 
        1.3312000000000002`}, {8.56, 1.3932128}, {8.72, 1.4563584}, {8.88, 
        1.5206176}, {9.04, 1.5859712}, {9.2, 1.6524}, {9.36, 1.7198848}, {
        9.52, 1.7884064}, {9.68, 1.8579456}, {9.84, 1.9284832}, {10, 2.}, {
        10, -0.2}, {2, -0.2}}]], 
     PolygonBox[{{10, 2}, {11, 2.45}, {11, -0.2}, {10, -0.2}}]}}, 
   {Thickness[0.0025], 
    LineBox[{{0, 0}, {0, 0.5}}], {LineBox[{{0, 0}, {2, 0}}], 
     LineBox[NCache[{{2, 0.}, {Rational[54, 25], 0.0009568000000000001}, {
        Rational[58, 25], 0.0038144}, {Rational[62, 25], 0.0085536}, {
        Rational[66, 25], 0.0151552}, {Rational[14, 5], 0.0236}, {
        Rational[74, 25], 0.0338688}, {Rational[78, 25], 0.0459424}, {
        Rational[82, 25], 0.0598016}, {Rational[86, 25], 0.0754272}, {
        Rational[18, 5], 0.09280000000000001}, {
        Rational[94, 25], 0.11190079999999998`}, {
        Rational[98, 25], 0.1327104}, {
        Rational[102, 25], 0.15520959999999998`}, {
        Rational[106, 25], 0.1793792}, {Rational[22, 5], 0.2052}, {
        Rational[114, 25], 0.23265280000000002`}, {
        Rational[118, 25], 0.26171839999999996`}, {
        Rational[122, 25], 0.2923776}, {Rational[126, 25], 0.3246112}, {
        Rational[26, 5], 0.3584}, {Rational[134, 25], 0.39372480000000004`}, {
        Rational[138, 25], 0.43056639999999996`}, {
        Rational[142, 25], 0.4689056}, {Rational[146, 25], 0.5087232}, {
        6, 0.55}, {Rational[154, 25], 0.5927167999999998}, {
        Rational[158, 25], 0.6368544}, {
        Rational[162, 25], 0.6823935999999999}, {
        Rational[166, 25], 0.7293151999999999}, {
        Rational[34, 5], 0.7776000000000001}, {
        Rational[174, 25], 0.8272288000000001}, {
        Rational[178, 25], 0.8781824}, {Rational[182, 25], 0.9304416}, {
        Rational[186, 25], 0.9839871999999998}, {Rational[38, 5], 1.0388}, {
        Rational[194, 25], 1.0948608}, {Rational[198, 25], 1.1521504}, {
        Rational[202, 25], 1.2106496}, {
        Rational[206, 25], 1.2703392000000002`}, {
        Rational[42, 5], 1.3312000000000002`}, {
        Rational[214, 25], 1.3932128}, {Rational[218, 25], 1.4563584}, {
        Rational[222, 25], 1.5206176}, {Rational[226, 25], 1.5859712}, {
        Rational[46, 5], 1.6524}, {Rational[234, 25], 1.7198848}, {
        Rational[238, 25], 1.7884064}, {Rational[242, 25], 1.8579456}, {
        Rational[246, 25], 1.9284832}, {10, 2.}}, {{2, 0.}, {2.16, 
        0.0009568000000000001}, {2.32, 0.0038144}, {2.48, 0.0085536}, {2.64, 
        0.0151552}, {2.8, 0.0236}, {2.96, 0.0338688}, {3.12, 0.0459424}, {
        3.28, 0.0598016}, {3.44, 0.0754272}, {3.6, 0.09280000000000001}, {
        3.76, 0.11190079999999998`}, {3.92, 0.1327104}, {4.08, 
        0.15520959999999998`}, {4.24, 0.1793792}, {4.4, 0.2052}, {4.56, 
        0.23265280000000002`}, {4.72, 0.26171839999999996`}, {4.88, 
        0.2923776}, {5.04, 0.3246112}, {5.2, 0.3584}, {5.36, 
        0.39372480000000004`}, {5.52, 0.43056639999999996`}, {5.68, 
        0.4689056}, {5.84, 0.5087232}, {6, 0.55}, {6.16, 
        0.5927167999999998}, {6.32, 0.6368544}, {6.48, 0.6823935999999999}, {
        6.64, 0.7293151999999999}, {6.8, 0.7776000000000001}, {6.96, 
        0.8272288000000001}, {7.12, 0.8781824}, {7.28, 0.9304416}, {7.44, 
        0.9839871999999998}, {7.6, 1.0388}, {7.76, 1.0948608}, {7.92, 
        1.1521504}, {8.08, 1.2106496}, {8.24, 1.2703392000000002`}, {8.4, 
        1.3312000000000002`}, {8.56, 1.3932128}, {8.72, 1.4563584}, {8.88, 
        1.5206176}, {9.04, 1.5859712}, {9.2, 1.6524}, {9.36, 1.7198848}, {
        9.52, 1.7884064}, {9.68, 1.8579456}, {9.84, 1.9284832}, {10, 2.}}]], 
     LineBox[{{10, 2}, {11, 2.45}}]}}, 
   GeometricTransformationBox[{{LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQjQ6W/94TMGl3pb1IyKWYR9oh9hB+pz3Hgd+LJHhK
7Pfu6d2z1meyvYiX6+rUoDao/Ex7qY8+jo19k+09ZMuKrEUX2NvfypBj/TcX
qn6xPTOnoM5vqaX2RjFL2RRaltlPb0y6u/zLaqj+lfbCnAqyuRs22svMvjKL
5fMa+4D35XIpM7ZCzdtgP2MmCOy0Z37bOP0LUN1z590i52fthZq/2V5gKid3
8sED9hU9Mx+mvdhib/zTYVH+nENQ+7bZR4RPPXcr6Ij9W+2N2jfld9iH1J35
euPmUaj9O+3LfucXnlQ/bp94+kSpd/hu+x8uT+2KTU5A3bPHftbuxisWP0/Y
X8t6sH9v3z77T1/uX3EsPAl13wH7WWD3nbQHADjboYY=
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ3eT6RkNx3zH7WTNB4OR+AXsLtVC3Y/ZeAWoCrzxO
7l+g47Zo6uWj9jPvZvLfiDix/8TOJo/zWUftIz4YPPE5f2x/mKfvs/UCR+1D
Yt08f249sv/ru843HSeP2HMl/w+UkDq0fxt3hrnJzCP2BlpK7BYS+/bL2X46
/rvpiP2sjRdCu+227394KIejtfOIvZTTs48bl6zfr55oLHdg3RF77ZVtb66y
LNjfcMV60+3PR+wZoOCXoX2tbeRRmLx9W0rLsfp7R2H67aetF31a3HQMZr49
g//0zZrOx2H22wsxHz3+W/YEzH32bnpTFBbwn4S5374r/+pDG5FTMP/Zm25e
MqtB/TTM//bl0xbV7nU5Awsf+z25SffZ0s/Cws8eABtwpC8=
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ/cfrjdc39kv2s2aCwMn9h9wneQqcuWjvFaAm8Mrj
5P4uu5ntGyZdtJ95N5P/RsSJ/XKt26N84y7aR3wweOJz/tj+p2fmrLQ1vGgf
Euvm+XPrkf1b5HfrrOK9aM+V/D9QQurQflE9rUv1Xy/YG2gpsVtI7Nt/yi1/
VvKrC/azNl4I7bbbvn9V5xqrFW8v2Es5Pfu4ccn6/edu9B91Zbhor72y7c1V
lgX7q4Sm9F9WumjPAAXmB0VLW0Lh8vZ1UTtmqs64CNNvz8bAuFL+1UWY+fa7
zjtOqPK6BLPf/vDKiFmPt1+Cuc8+xv7Asa0Gl2Hut2d4kKDOsvkyzH/2VxpP
MC+zuQLzv31ZsXupy+krsPCxl4hXV8uMuQoLP3sAWcSkEQ==
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbVacxHhnww37WTNB4OT+P/kcDN9Kbth7BagJvPI4
uf9oGr/dNOsb9jPvZvLfiDixP3KtrqAx+w37iA8GT3zOH9sv/1UoQfnWdfuQ
WDfPn1uP7H/vbvi4f9t1e67k/4ESUof2+4ct6Eidd93eQEuJ3UJi336W/KcB
npOv28/aeCG02277/qcblT72TrtuL+X07OPGJev3czCy1WivvG6vvbLtzVWW
Bfu3WHG57Tx93Z4BCopedmtn/YPL229v0gvgdrwB02/voFEezzr5Bsx8+6/f
t7slfL4Bs9/+78VzAScTbsLcZz893ax29s2bMPfbW3Jcv/sy+hbMf/YCq+x2
dT+9BfO//YbZe7W1Sm7Dwsc+uH3uHT/WO7DwswcAJjWkEA==
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQXTD7xvaDkfftZ80EgZP7zWbUbbste9/eK0BN4JXH
yf3/+1q/VD+5Zz/zbib/jYgT+ydfXXxcYsM9+4gPBk98zh/bHyXbKcbZfM8+
JNbN8+fWI/s1C5bPLI2/Z8+V/D9QQurQ/q46MXtv93v2BlpK7BYS+/bbTY9m
17e5Zz9r44XQbrvt++VvzVhebH/PXsrp2ceNS9bvd9KsMRIMumevvbLtzVWW
BfvfJTX8mVdyz54BCtYIMj3yXw6Xt/+4agnbx5dw/fZVAW9FX1vfh5lvr6+g
99d1zn2Y/fYytYuar7M8gLnP/oX7tZkOjg9g7re3mqF2Kr3pAcx/9qqZUTss
jj+A+d/+20PJj+18D2HhY3/seqenVPhDWPjZAwBkNKWe
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQfTVRfXsw42P7WTNB4OR+i4SqbQmPH9l7BagJvPI4
uX/O7dqrG449sp95N5P/RsSJ/c/+8djXr3lkH/HB4InP+WP7Ty2qT/s+9ZF9
SKyb58+tR/YbneFbodvyyJ4r+X+ghNSh/UnBx6okKh7ZG2gpsVtI7Nu/5/6L
uK6iR/azNl4I7bbbvl+3kX29TskjeymnZx83Llm/f59GZUl17SN77ZVtb66y
LNg/1bU68lDfI3sGKPgsY3NGagVc3n5aZm9c9km4fvuoPYZpGZ/g5tubqFy6
OVXpMcx+e8uJd+O8Ih/D3GfPFiNYunnqY5j77cPWJC69de0xzH/2TrVTJ6+W
fgLzv73Qt5Azv5KewMLH/snrIyq9q5/Aws8eAJLBqaQ=
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ/ak0adKx0Gf2s2aCwMn9YSVbJ142f2bvFaAm8Mrj
5P5d73dsUJZ+Zj/zbib/jYgT+1mEPaQ+MTyzj/hg8MTn/LH9z7ftcsx69dQ+
JNbN8+fWI/v9H3g2L7jx1J4r+X+ghNSh/fXpjGHdZ57aG2gpsVtI7Nt/87Oy
1d9jT+1nbbwQ2m23fb/XVKeu+See2ks5Pfu4ccn6/bdttvi/u/jUXntl25ur
LAv2b4zcZmL6+Kk9AxQIGJYv7/0Dl7ffXHvC8p7sM5h++4oLOY633Z7BzLcP
tODdylH+DGa/fdhSCau9a5/B3GevUuAToPbqGcz99qUH5jT4aj+H+c8+fuKF
PLmC5zD/2+tzTVieu/05LHzsGcGuegELP3sAAzClKg==
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQzd81N9dy1Uv7WTNB4OT+4o4POW49L+29AtQEXnmc
3H+d+Uv3tPyX9jPvZvLfiDixX1G9+WtK6Ev7iA8GT3zOH9vPcvqrzF27l/Yh
sW6eP7ce2Z/zpSVOWPelPVfy/0AJqUP751bbGP5TeGlvoKXEbiGxb/839njR
AmmgfRsvhHbbbd+fvrI2VUj2pb2U07OPG5es3/8j4L1WotpLe+2VbW+usizY
fz73I/8K85f2DFCg67qpiSEQLm9/YSKzaGARXL/91CfLZfxmw823z/fxmFB9
Gm6/ffHOYFEDplcw99k7trRrz7R7BXO//aQr16MP1L+C+c++Zim318Qjr2D+
t/eRO930gPs1LHzs5USsbxeFvIaFnz0A1bihrA==
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQrTPvhseaf2/sZ80EgZP7J8zR9tj54I29V4CawCuP
k/u/iOuncx55Yz/zbib/jYgT++2t9124vvKNfcQHgyc+54/tV7xv8MN/8hv7
kFg3z59bj+zv5Dhg2db4xp4r+X+ghNSh/bv6y3kKS9/YG2gpsVtI7NsvIjPr
w6N8oH0bL4R2223f37J3h0Nr4Rt7KadnHzcuWb9fNFWL7UrVG3vtlW1vrrIs
2P+mUee1VM8bewYo8Ip8G1u8FC5v/3ap3YfDx+D67Tf9ePT9wHu4+fY9Cc3Z
7+Tfwuy3n3C278OisLcw99nHzTjExjP5Lcz99utfCJkbX3kL85/9rJ1uqiyS
72D+t880YosLTngHCx97a42ybU9XvIOFnz0A4dyqIg==
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQrXqTc1K/5gf7WTNB4OT+sIjNgtOkPth7BagJvPI4
uZ9TzFTRjueD/cy7mfw3Ik7sj/b/udrr33v7iA8GT3zOH9tv/zn78qHn7+1D
Yt08f249sn+ZzG+Rn1ff23Ml/w+UkDq0//riTc8fn3xvb6ClxG4hsW+/kcHV
06FH3tvP2nghtNtu+/6FFz9L/zj63l7K6dnHjUvW7zeqTH3odv69vfbKtjdX
WRbs55yWfqz3wXt7BijIyNWwfPYTLm/PdndP6mzeDzD99uls/S8llT7AzLcP
sYpfbGD1AWa//bUPT552hX6Auc/e7tq/gv3FH2Dut0/7p8YZPOUDzH/2t585
NOzeBve/vfPiBTLJt+DhY68z74bHmn/w8LMHADbxrIM=
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbZK8/P+Jyx/tZ80EgZP7Ux8F1J8/8tHeK0BN4JXH
yf0SCy71lW/7aD/zbib/jYgT+/cYzjoct/KjfcQHgyc+54/tX9ccfF1q3kf7
kFg3z59bj+xPkpD+YTr1oz1X8v9ACalD+3/dLkvU7v9ob6ClxG4hsW+/hlJH
cEoP0L6NF0K77bbvv1c0vdq096O9lNOzjxuXrN+/wi3g3p2JH+21V7a9ucqy
YL9w6MWAhlkf7Rmg4NABwy6d5XB5e5H0qMtXtsP125dN0AkPPgM33z7pyB+B
rCdw++2fVTUFH/kPd5+9T8Kcez9kP8Hcb1/ScaSsx+4TzH/2Lwvuvf2S8Anm
f/sgXbuuOS2fYOFjb61Rtu3pik+w8LMHAH6Qrdk=
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7fTWJZep7rP9rJkgcHJ/Sc67Nxz5n+29AtQEXnmc
3K+mVfBnQ8Jn+5l3M/lvRJzYf2q3ueGM4M/2ER8MnvicP7Z/D+9HlxCPz/Yh
sW6eP7ce2V+4aEdqvv1ne67k/4ESUof2c6aJnE+x/GxvoKXEbiGxb7/pGtWD
c82A9m28ENptt33/uz8mL/PMP9tLOT37uHHJ+v3bLrz1FrP5bK+9su3NVZYF
+5Xu5+3b6fLZngEKLnqd/54aCJe3V/743YEvCa7fvkXq1JGeMrj59oV+s+oW
98Htt//ConDw70q4++yjX1n6GJ2Au9++WSjpydEXcP/Z//hVHa3H/QXmf/vE
7be/X9X7Agsfe89NwirywV9g4WcPAGweqR0=
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQHVD+6Ja1xlf7WTNB4OT+5m/dUU6SX+29AtQEXnmc
3G+yhTfrFddX+5l3M/lvRJzYf9P16ryLf7/YR3wweOJz/tj+09P7NvV++mIf
Euvm+XPrkf31OmGXV7z8Ys+V/D9QQurQfvEPG23mPf5ib6ClxG4hsW+/i9lh
vesPvtjP2nghtNtu+/4/bZfCVjz8Yi/l9OzjxiXr9x+N6t7p/+yLvfbKtjdX
WRbsN8jk0fn87os9AxTcv5KTOv83XN7eqHrqOneerzD99pOWpBsdU/gKM9++
8Yb5mzsWX2H22zP379UzD/kKc599Zsn1ndlFX2Hut58053/g/0lfYf6zZ2uV
PJm+Fe5/+3zHylT+m/DwsY+w2Tgx4i88/OwB0cyuVg==
       "]]}, 
     {Opacity[0.625], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQE/7GEsFuf1uS7PvtuLhFyKeaQdYs/ZFne748x3
e44DvxdJ8JTY857k9Ty7CSjv5bo6NajNXpBn7zbBmd/tpT76ODb2TbYX889R
Cav/bm9/K0OO9d9ce6lJ0pNmpX63Z+YU1PkttdRe7uqp//e8v9tPb0y6u/zL
antliapcZaPv9sKcCrK5Gzbaq0dr3k6X+G4f8L5cLmXGVnudeTc81vz7Zj9j
JgjstDd42L7tw5Nv9s+dd4ucn7XX3kTFXMX09Dd7gamc3MkHD9hbpD+bWLnx
m73xT4dF+XMO2duumvp/7/Rv9hHhU8/dCjpi7/jWJZep7pt9SN2ZrzduHrV3
M/hyyy3lm33Z7/zCk+rH7b2KF3t0e32z/+Hy1K7Y5IS937agbecNvtnP2t14
xeLnCfvgn4wqIuLf7D99uX/FsfCkfbjNxokRf7/azwK776Q9AB99n1c=
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7SFbVmQtesB+1kwQOGnf+8X0Sov5QXuvADWBVx4n
7c9fN95+MOSQ/cy7mfw3Ik7YV0kzF7BmHLaP+GDwxOf8Mfv9MS6Gi3KO2IfE
unn+3HrE/lO7cJdb3FF7ruT/gRJSh+xZbBznSVgeszfQUmK3kNhnn3f7UM65
n8fsZ228ENptt92+Ti2k+9Dc4/ZSTs8+blyy3p47cuYVFuUT9tor295cZVlg
37Jtzvy0jhP2DFBwT3OpcdNZuPx+lRPZnns/nYDp3//M91mn288TMPP3+9UX
SPE9PgGzf7/AHL/UnZtOwNy3f71jd/ak7BMw9++3uRjKWSx4Aua//Slxk9av
WXEc5v/9X7wXaL81PQ4Ln/1Nrm80FPcdg4XffgAMfaIm
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQvSc36T5b+ln7WTNB4KQ9o6uSY0DnOXuvADWBVx4n
7V00FFR6l523n3k3k/9GxAn771vL817EXLCP+GDwxOf8MftZYRLnze5fsA+J
dfP8ufWIvcmb+t8cERftuZL/B0pIHbK3OTaNtejoRXsDLSV2C4l99p+mXn9z
RvWS/ayNF0K77bbbV1kr/DlWfsleyunZx41L1tsfuHJIIWPXJXvtlW1vrrIs
sK9pdmGTfHvJngEKNPd6XFjGfxkmv9+HRyfaRekyTP9+Xf/M3x2ql2Hm73+U
vu5wjtRlmP37ncpkM52YLsPct1/opPWbdfcuwdy//4aAovX8jZdg/tufE27P
Z1N7Ceb//aZ+bj53nC/Bwmf/H683Xt/YL8HCbz8ABhuhMQ==
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQLRGvrpYZc9V+1kwQOGm/24v9eu/bq/ZeAWoCrzxO
2sfYtHno1Fyzn3k3k/9GxAl7o3tvVc6xXreP+GDwxOf8MfsrdX2tMh3X7UNi
3Tx/bj1inyfybeM7hhv2XMn/AyWkDtmXvePZE553w95AS4ndQmKfvc4+38Wb
zt2wn7XxQmi33Xb7LcnTNq1RuGkv5fTs48Yl6+1//bG47pt80157ZdubqywL
7Let3rXn39Sb9gxQkPx0X1vPDrj8/jaTRYJap+H692eU39+Yd+4mzPz9MhNU
qoIO34TZv79m3mR5jdU3Ye7b7/Nx46Ip7Tdh7t8vZDn9Y0vUTZj/9i+v33pE
Ue0mzP/788v2MB16cwMWPvvNipMY72y4AQu//QCaXaiG
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQHdw+944f6x37WTNB4KT916La3uJpd+y9AtQEXnmc
tJ+W8uefoOpd+5l3M/lvRJywz2FLub153V37iA8GT3zOH7PnX85iw2R4zz4k
1s3z59Yj9itscjKurLxnz5X8P1BC6pD9RrHmIlvx+/YGWkrsFhL77NOeHY6c
UX7fftbGC6Hddtvt33XzZE46ed9eyunZx41L1tvPmnT9mCTbA3vtlW1vrrIs
sP+ROcOySP6BPQMUnG+bJbfTAC6/P0GP5wm71QOY/v0Xz2uZrLJ+ADN/v3aM
r4SM2QOY/ftjHrO8ZtN6AHPf/sM8U3RsJR7A3L9/2Qa2kK2MD2D+2/9wuXY1
+/n7MP/vXznPaOfyqfdh4bO/YPaN7Qcj78PCbz8Ah/eiSw==
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQfex6p6dU+EP7WTNB4KT9jLM/F66Z/9DeK0BN4JXH
SfsMt523fj97aD/zbib/jYgT9sHib0+c0X5kH/HB4InP+WP2S9Jtf37OeWQf
Euvm+XPrEftCo0L+2JWP7LmS/wdKSB2yL5tfM0XwwSN7Ay0ldguJffYB7LIc
9gKP7WdtvBDabbfdXiTqIL+N5WN7KadnHzcuWW+/fZnQop6ox/baK9veXGVZ
YC9Wd1nkafFjewYoeDPr6k/tVrj8/jon9/1VfXD9+989TuWXnQA3f79HQcfn
vq7HMPv3V3y3P1ZZ9xjmvv0PFM6zb8h5DHP//iNHHPU1wh7D/Lef78WFGd+s
H8P8v78o+cp2N/nHsPDZfzVRfXsw42NY+O0HAPt6p+Y=
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ/eT1EZXe1U/sZ80EgZP2Wx+a1Mp/eWLvFaAm8Mrj
pH1r1JetedZP7WfezeS/EXHCvkBbY4l9w1P7iA8GT3zOH7M/WF1xJe3gU/uQ
WDfPn1uP2Pe5rXl1/u9Te67k/4ESUofsJ2/ent9i8szeQEuJ3UJin32udMTj
jSnP7GdtvBDabbfd3jDvz6t1vc/spZyefdy4ZL39lV2+tf/XPbPXXtn25irL
AnvjSXwfwk88s2eAAq71Alfn3YTL758V1jTr7SO4/v3cPxa86n8CN39/asvh
c4z34fbvn8ZdvfDNpWcw9+3/a8L1WOngM5j79z+4UcM1e9UzmP/2a//hLsmc
8Azm//395fyTdxY/g4XP/k+lSZOOhT6Dhd9+AEeusFo=
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQzcgAAi/sZ80EgZP2l77mR0zyeGHvFaAm8MrjpP2i
PP2JD/tf2M+8m8l/I+KEfa99cv2mKy/sIz4YPPE5f8z+Xv/m9TdFX9qHxLp5
/tx6xH511POjTkEv7bmS/wdKSB2y33D8k9f3jpf2BlpK7BYS++y79CfvU9n5
0n7Wxguh3Xbb7f2bzI8pPnppL+X07OPGJevtP57riChifmWvvbLtzVWWBfYB
yzxPn5J5Zc8ABeqHvTcI6sHl9+/I2luaYP4Kpn+/Bs+do0yWr2Dm72+a8W9l
ifErmP37N8tvq4lXfwVz334pT9d9U0Vfwdy//++b7U95/7+E+W+/h4C7/50n
L2H+37+m2ytP58RLWPjs5++am2u56iUs/PYDAAqCpuE=
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQLSdifbso5LX9rJkgcNL+A+dqY9a5r+29AtQEXnmc
tN/flJUT8uS1/cy7mfw3Ik7YrwqeF6Wq+cY+4oPBE5/zx+x/L37X5ZP1xj4k
1s3z59Yj9ifzlBZuXfbGniv5f6CE1CH7s7d11bLuvrE30FJit5DYZ7/c+dzM
6bxv7WdtvBDabbfdPmda0cIpZm/tpZyefdy4ZL093+PDxk/D39prr2x7c5Vl
gX3urpZltoVv7RmgwOV6W3dLE1x+/9W6HwGXu+H697sqiC8s7YWbv3/+GsvW
5+1vYfbvv2D8MfxS9VuY+/abxzbM5Mh6C3P/finGzwcagt/C/Lc/VaVJy9/y
Lcz/+0/Ob/WcL/MWFj77debd8Fjz7w0s/PYDAEk2qF0=
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQba1Rtu3pinf2s2aCwEl7XrlnfBUf39l7BagJvPI4
aX932lL34xbv7WfezeS/EXHC/lj6TdMZte/tIz4YPPE5f8xeYodm2v597+1D
Yt08f249Yv+sKbZG4/d7e67k/4ESUofsv5ZvaXgn8cHeQEuJ3UJin/2j1S1W
rIYf7GdtvBDabbfd3uVq2L5m1w/2Uk7PPm5cst5+WnU9u07YB3vtlW1vrrIs
sHd9ft/hRtIHewYo2PA1YXN1Nlx+f9VJSTHlArj+/YZSmnZfCuDm749LsDLQ
zYPbv/+b8rSZShkfYO7bv2pH7C7b+A8w9++fwyV+7mfwB5j/9jvMucf00O0D
zP/7P0cmCHVafICFz37Vm5yT+jU/wMJvPwBuoqYL
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQrTPvhseafx/sZ80EgZP2ojMFSr8qfbT3ClATeOVx
0r42tEBwrttH+5l3M/lvRJyw/2Tb1cGa+dE+4oPBE5/zx+yl0jYpzOz8aB8S
6+b5c+sR+ybvM6vPLv9oz5X8P1BC6pA9C1PQO/XDH+0NtJTYLST22X80VVph
d/uj/ayNF0K77bbbB8V/0d77/qO9lNOzjxuXrLdfwipbmsrwyV57ZdubqywL
7IMLa9cJ8n6yZ4CC/fX/FLaKwuX3dwRvb46R+gTTv99hybHVutKfYObvz311
fW6axCeY/ftZ1xmzxwh9grlv/06n3+rlnJ9g7t+/asoWa+N/cP/t91erKZD6
CPf/fqYnf+sPPYKHz36T5OX/T1z+CAu//QBcPqV+
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQba1Rtu3pik/2s2aCwEl7ZeV1j/TOfrL3ClATeOVx
0r7nPm/9tQ+f7GfezeS/EXHCnvGE+jc74c/2ER8MnvicP2av+cG/75LxZ/uQ
WDfPn1uP2PdfzZRkD/psz5X8P1BC6pC9cM/76MTcz/YGWkrsFhL77BkO7Bet
aP1sP2vjhdBuu+32iS8nzvw287O9lNOzjxuXrLff3L/r0bxVn+21V7a9ucqy
wD7pt5SM9/bP9gxQcI5zTt+7/XD5/dPuhnycegSuf7+fXopk+lG4+furS0q5
FxyC279f2OJiydQ9cPftP35mxtQNm+Hu379LLmhlzgq4//bHbZC8Fzz7M8z/
+wXyZr/93fMZFj77nd665DLVfYaF334AKmertw==
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7blJWEU++Iv9rJkgcNLeaK13QEb5F3uvADWBVx4n
7Wdnrn7DP/uL/cy7mfw3Ik7Y8wcdTa7Y+8U+4oPBE5/zx+wtqt7+5r73xT4k
1s3z59Yj9vPi2dsd/nyx50r+HyghdcheUaz35Czxr/YGWkrsFhL77Pm9Yps3
6n+1n7XxQmi33Xb7/GJ9dgOXr/ZSTs8+blyy3v6gZETAjZCv9tor295cZVlg
X9i6o7Ml8as9AxTcmWz5Rz0LLr9/SfqnuPN5cP37Y3cwti/Ih5u/v/OfUOXN
HLj9+5UO5T06l/YV5r7918LMmF/FfoW5f/+JFe/FlgV9hflvf67Vdu9e168w
/++X+2ERbWr+FRY++wPKH92y1vgKC7/9APdHpPs=
       "]]}}, {0, 0.25}], 
   {Thickness[0.0015], LineBox[{{1.5, 0.1}, {1.5, 0.4}}]}, 
   {Arrowheads[0.015], ArrowBox[{{10.45, 1.3}, {10.45, 2}}], 
    ArrowBox[{{10.45, 0.7}, {10.45, 0}}], InsetBox["\<\"h\"\>", {10.45, 1.}]}, 
   {Dashing[0.00375], LineBox[{{10.2, 0}, {10.7, 0}}], 
    LineBox[{{10.2, 2}, {10.7, 2}}]}, InsetBox["\<\"k\"\>", {0.75, 0.75}]},
  BaseStyle->{12, Italic, FontFamily -> "Times"}]], "Output",
 CellChangeTimes->{3.6644526347063923`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x3", "=", "2"}], ",", 
     RowBox[{"x4", "=", "13"}], ",", 
     RowBox[{"x5", "=", "15"}], ",", 
     RowBox[{"y0", "=", 
      RowBox[{"-", ".2"}]}], ",", 
     RowBox[{"y2", "=", "3"}], ",", 
     RowBox[{"arrowAbove", "=", "1.1"}], ",", 
     RowBox[{"wArrow", "=", ".6"}]}], "}"}], ",", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xR", "=", 
        FractionBox[
         RowBox[{"x4", "+", "x5"}], "2"]}], ",", 
       RowBox[{"wDash", "=", ".8"}], ",", 
       RowBox[{"dashWidth", "=", ".5"}], ",", 
       RowBox[{"curve", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x3", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
          RowBox[{"CubicSmoothShift", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"x3", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x4", ",", "y2"}], "}"}]}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x4", ",", "y2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x5", ",", "y2"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"GrayLevel", "[", ".8", "]"}], ",", 
           RowBox[{"PolygonBelowLine", "[", 
            RowBox[{"y0", ",", "curve"}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", ".0025", "]"}], ",", "curve"}], "}"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"DoubleArrow", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"xR", ",", "y2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"xR", ",", "0"}], "}"}], ",", "\"\<\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\)\>\"", ",", 
            RowBox[{"TextGap", "\[Rule]", ".2"}], ",", 
            RowBox[{"ArrowDirectives", "->", 
             RowBox[{"{", 
              RowBox[{"Arrowheads", "[", ".015", "]"}], "}"}]}]}], "]"}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", ".00375", "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"xR", "-", 
                 FractionBox["wDash", "2"]}], ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"xR", "+", 
                 FractionBox["wDash", "2"]}], ",", "0"}], "}"}]}], "}"}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"SimpleCar", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x3", "/", "2"}], ",", "0"}], "}"}], ",", 
           RowBox[{"Scale", "\[Rule]", "1.5"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"SimpleCar", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"xR", ",", "y2"}], "}"}], ",", 
            RowBox[{"Scale", "\[Rule]", "1.5"}], ",", 
            RowBox[{"TireColor", "\[Rule]", 
             RowBox[{"Lighter", "[", 
              RowBox[{
               RowBox[{"GrayLevel", "[", ".4", "]"}], ",", ".55"}], "]"}]}], 
            ",", 
            RowBox[{"CarColor", "\[Rule]", 
             RowBox[{"Lighter", "[", 
              RowBox[{
               RowBox[{"GrayLevel", "[", ".7", "]"}], ",", ".55"}], "]"}]}]}],
            "]"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Arrowheads", "[", ".03", "]"}], ",", 
           RowBox[{"LabeledArrow", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x3", "/", "2"}], ",", "arrowAbove"}], "}"}], "-", 
              RowBox[{"{", 
               RowBox[{"wArrow", ",", "0"}], "}"}]}], ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x3", "/", "2"}], ",", "arrowAbove"}], "}"}], "+", 
              RowBox[{"{", 
               RowBox[{"wArrow", ",", "0"}], "}"}]}], ",", 
             "\"\<\!\(\*SubscriptBox[\(v\), \(0\)]\)\>\""}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"LabeledArrow", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"xR", ",", "y2"}], "}"}], "+", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "wArrow"}], ",", "arrowAbove"}], "}"}]}], ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"xR", ",", "y2"}], "}"}], "+", 
              RowBox[{"{", 
               RowBox[{"wArrow", ",", "arrowAbove"}], "}"}]}], ",", "\"\<\!\(\*
StyleBox[\"v\",
FontSlant->\"Italic\"]\)\[VeryThinSpace]=\[VeryThinSpace]?\>\""}], "]"}]}], 
          "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
       RowBox[{"BaseStyle", "->", 
        RowBox[{"{", 
         RowBox[{"12", ",", 
          RowBox[{"FontFamily", "->", "\"\<Times\>\""}]}], "}"}]}]}], "]"}]}],
     "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.418149660819845*^9, 3.4181496934016733`*^9}, {
   3.41814994318474*^9, 3.418149950295899*^9}, {3.418152661489334*^9, 
   3.4181526939235277`*^9}, {3.418152727075488*^9, 3.418153052636058*^9}, {
   3.4181530894899063`*^9, 3.418153130727453*^9}, {3.418153202074065*^9, 
   3.418153286360054*^9}, {3.418153376435025*^9, 3.4181533984047403`*^9}, {
   3.4181534359129333`*^9, 3.418153593441408*^9}, {3.418153631828081*^9, 
   3.418153687254974*^9}, {3.418153761907482*^9, 3.418153793903325*^9}, {
   3.418153835013888*^9, 3.418153974626357*^9}, {3.418154015158737*^9, 
   3.4181540470966167`*^9}, 3.418154085269148*^9, {3.4181541352059603`*^9, 
   3.418154223070229*^9}, {3.418154336863247*^9, 3.418154352564102*^9}, {
   3.418154411104157*^9, 3.418154504217519*^9}, {3.418154541968686*^9, 
   3.418154554030405*^9}, {3.418154635786159*^9, 3.41815495927206*^9}, {
   3.418155058574604*^9, 3.418155075490284*^9}, {3.4181551976796093`*^9, 
   3.418155370643991*^9}, {3.418155405172288*^9, 3.418155418970409*^9}, 
   3.41815545629888*^9, {3.4181555005522957`*^9, 3.418155541648019*^9}, {
   3.418155596815206*^9, 3.4181556055263853`*^9}, {3.41815565176683*^9, 
   3.4181557896598063`*^9}, 3.418156860940445*^9, {3.418224157868457*^9, 
   3.418224193388474*^9}, 3.437916534531859*^9, {3.437916658246944*^9, 
   3.4379166716647577`*^9}, 3.445425295758252*^9, {3.4454253687097197`*^9, 
   3.4454254237202682`*^9}, {3.4454254550752373`*^9, 3.445425483168795*^9}, {
   3.445425514996162*^9, 3.4454256128379097`*^9}, {3.445425675669579*^9, 
   3.445425745013585*^9}, {3.4454258577406683`*^9, 3.445425929182577*^9}, {
   3.4454259700668087`*^9, 3.4454261146841917`*^9}, {3.4454261712314987`*^9, 
   3.445426173077598*^9}, {3.445426223799011*^9, 3.445426244436143*^9}, {
   3.4454262792171173`*^9, 3.445426314514647*^9}, {3.445426391056975*^9, 
   3.445426560049901*^9}, 3.481907615213306*^9, {3.481907736891903*^9, 
   3.481907746835342*^9}, 3.481907859409362*^9, {3.481907911227624*^9, 
   3.48190793187959*^9}, {3.4819080038980093`*^9, 3.48190801114303*^9}, {
   3.481908049693572*^9, 3.481908071975937*^9}, 3.481908143628673*^9, 
   3.481908185166098*^9, {3.481908231364771*^9, 3.481908240810288*^9}, {
   3.481908288297306*^9, 3.4819082888079023`*^9}, 3.481908340856855*^9, {
   3.481928545361277*^9, 3.481928573609291*^9}, {3.623939359573185*^9, 
   3.6239394899476233`*^9}, {3.623939538868451*^9, 3.623939575661428*^9}, {
   3.623939623487735*^9, 3.6239396539264393`*^9}, 3.623939739249374*^9, {
   3.623939775984536*^9, 3.6239397771327887`*^9}, {3.62393982715143*^9, 
   3.623939849358934*^9}, {3.623939883738014*^9, 3.623939891941774*^9}, {
   3.623939956392468*^9, 3.623940010143691*^9}, {3.623940049175556*^9, 
   3.623940062274391*^9}, {3.623940127817584*^9, 3.623940135351712*^9}, {
   3.623940190983708*^9, 3.623940197323371*^9}, {3.6239402571100388`*^9, 
   3.623940323132593*^9}, {3.62394035371483*^9, 3.623940377064431*^9}, 
   3.623940423627199*^9, {3.623940537750495*^9, 3.623940713214382*^9}, {
   3.6239407467195263`*^9, 3.623940828287916*^9}, {3.623940876880052*^9, 
   3.6239411293695383`*^9}, {3.623941793615827*^9, 3.62394180985359*^9}, 
   3.623942531948333*^9, {3.6239425705190067`*^9, 3.62394261064248*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.8], PolygonBox[{{0, 0}, {2, 0}, {2, -0.2}, {0, -0.2}}], 
    PolygonBox[
     NCache[{{2, 0}, {Rational[111, 50], Rational[111, 31250]}, {
       Rational[61, 25], Rational[219, 15625]}, {
       Rational[133, 50], Rational[486, 15625]}, {
       Rational[72, 25], Rational[852, 15625]}, {
       Rational[31, 10], Rational[21, 250]}, {
       Rational[83, 25], Rational[1863, 15625]}, {
       Rational[177, 50], Rational[2499, 15625]}, {
       Rational[94, 25], Rational[3216, 15625]}, {
       Rational[199, 50], Rational[8019, 31250]}, {
       Rational[21, 5], Rational[39, 125]}, {
       Rational[221, 50], Rational[5808, 15625]}, {
       Rational[116, 25], Rational[6804, 15625]}, {
       Rational[243, 50], Rational[15717, 31250]}, {
       Rational[127, 25], Rational[8967, 15625]}, {
       Rational[53, 10], Rational[81, 125]}, {
       Rational[138, 25], Rational[11328, 15625]}, {
       Rational[287, 50], Rational[25143, 31250]}, {
       Rational[149, 25], Rational[13851, 15625]}, {
       Rational[309, 50], Rational[15162, 15625]}, {
       Rational[32, 5], Rational[132, 125]}, {
       Rational[331, 50], Rational[35721, 31250]}, {
       Rational[171, 25], Rational[19239, 15625]}, {
       Rational[353, 50], Rational[20631, 15625]}, {
       Rational[182, 25], Rational[22032, 15625]}, {
       Rational[15, 2], Rational[3, 2]}, {
       Rational[193, 25], Rational[24843, 15625]}, {
       Rational[397, 50], Rational[26244, 15625]}, {
       Rational[204, 25], Rational[27636, 15625]}, {
       Rational[419, 50], Rational[58029, 31250]}, {
       Rational[43, 5], Rational[243, 125]}, {
       Rational[441, 50], Rational[31713, 15625]}, {
       Rational[226, 25], Rational[33024, 15625]}, {
       Rational[463, 50], Rational[68607, 31250]}, {
       Rational[237, 25], Rational[35547, 15625]}, {
       Rational[97, 10], Rational[294, 125]}, {
       Rational[248, 25], Rational[37908, 15625]}, {
       Rational[507, 50], Rational[78033, 31250]}, {
       Rational[259, 25], Rational[40071, 15625]}, {
       Rational[529, 50], Rational[41067, 15625]}, {
       Rational[54, 5], Rational[336, 125]}, {
       Rational[551, 50], Rational[85731, 31250]}, {
       Rational[281, 25], Rational[43659, 15625]}, {
       Rational[573, 50], Rational[44376, 15625]}, {
       Rational[292, 25], Rational[45012, 15625]}, {
       Rational[119, 10], Rational[729, 250]}, {
       Rational[303, 25], Rational[46023, 15625]}, {
       Rational[617, 50], Rational[46389, 15625]}, {
       Rational[314, 25], Rational[46656, 15625]}, {
       Rational[639, 50], Rational[93639, 31250]}, {13, 3}, {13, -0.2}, {
       2, -0.2}}, {{2, 0}, {2.22, 0.003552}, {2.44, 0.014016}, {2.66, 
       0.031104}, {2.88, 0.054528}, {3.1, 0.084}, {3.32, 0.119232}, {3.54, 
       0.159936}, {3.76, 0.205824}, {3.98, 0.256608}, {4.2, 0.312}, {4.42, 
       0.371712}, {4.64, 0.435456}, {4.86, 0.502944}, {5.08, 0.573888}, {5.3, 
       0.648}, {5.52, 0.724992}, {5.74, 0.804576}, {5.96, 0.886464}, {6.18, 
       0.970368}, {6.4, 1.056}, {6.62, 1.143072}, {6.84, 1.231296}, {7.06, 
       1.320384}, {7.28, 1.410048}, {7.5, 1.5}, {7.72, 1.589952}, {7.94, 
       1.679616}, {8.16, 1.768704}, {8.38, 1.856928}, {8.6, 1.944}, {8.82, 
       2.029632}, {9.04, 2.113536}, {9.26, 2.195424}, {9.48, 2.275008}, {9.7, 
       2.352}, {9.92, 2.426112}, {10.14, 2.497056}, {10.36, 2.564544}, {10.58,
        2.628288}, {10.8, 2.688}, {11.02, 2.743392}, {11.24, 2.794176}, {
       11.46, 2.840064}, {11.68, 2.880768}, {11.9, 2.916}, {12.12, 
       2.945472}, {12.34, 2.968896}, {12.56, 2.985984}, {12.78, 2.996448}, {
       13, 3}, {13, -0.2}, {2, -0.2}}]], 
    PolygonBox[{{13, 3}, {15, 3}, {15, -0.2}, {13, -0.2}}]}, 
   {Thickness[0.0025], LineBox[{{0, 0}, {2, 0}}], 
    LineBox[NCache[{{2, 0}, {Rational[111, 50], Rational[111, 31250]}, {
       Rational[61, 25], Rational[219, 15625]}, {
       Rational[133, 50], Rational[486, 15625]}, {
       Rational[72, 25], Rational[852, 15625]}, {
       Rational[31, 10], Rational[21, 250]}, {
       Rational[83, 25], Rational[1863, 15625]}, {
       Rational[177, 50], Rational[2499, 15625]}, {
       Rational[94, 25], Rational[3216, 15625]}, {
       Rational[199, 50], Rational[8019, 31250]}, {
       Rational[21, 5], Rational[39, 125]}, {
       Rational[221, 50], Rational[5808, 15625]}, {
       Rational[116, 25], Rational[6804, 15625]}, {
       Rational[243, 50], Rational[15717, 31250]}, {
       Rational[127, 25], Rational[8967, 15625]}, {
       Rational[53, 10], Rational[81, 125]}, {
       Rational[138, 25], Rational[11328, 15625]}, {
       Rational[287, 50], Rational[25143, 31250]}, {
       Rational[149, 25], Rational[13851, 15625]}, {
       Rational[309, 50], Rational[15162, 15625]}, {
       Rational[32, 5], Rational[132, 125]}, {
       Rational[331, 50], Rational[35721, 31250]}, {
       Rational[171, 25], Rational[19239, 15625]}, {
       Rational[353, 50], Rational[20631, 15625]}, {
       Rational[182, 25], Rational[22032, 15625]}, {
       Rational[15, 2], Rational[3, 2]}, {
       Rational[193, 25], Rational[24843, 15625]}, {
       Rational[397, 50], Rational[26244, 15625]}, {
       Rational[204, 25], Rational[27636, 15625]}, {
       Rational[419, 50], Rational[58029, 31250]}, {
       Rational[43, 5], Rational[243, 125]}, {
       Rational[441, 50], Rational[31713, 15625]}, {
       Rational[226, 25], Rational[33024, 15625]}, {
       Rational[463, 50], Rational[68607, 31250]}, {
       Rational[237, 25], Rational[35547, 15625]}, {
       Rational[97, 10], Rational[294, 125]}, {
       Rational[248, 25], Rational[37908, 15625]}, {
       Rational[507, 50], Rational[78033, 31250]}, {
       Rational[259, 25], Rational[40071, 15625]}, {
       Rational[529, 50], Rational[41067, 15625]}, {
       Rational[54, 5], Rational[336, 125]}, {
       Rational[551, 50], Rational[85731, 31250]}, {
       Rational[281, 25], Rational[43659, 15625]}, {
       Rational[573, 50], Rational[44376, 15625]}, {
       Rational[292, 25], Rational[45012, 15625]}, {
       Rational[119, 10], Rational[729, 250]}, {
       Rational[303, 25], Rational[46023, 15625]}, {
       Rational[617, 50], Rational[46389, 15625]}, {
       Rational[314, 25], Rational[46656, 15625]}, {
       Rational[639, 50], Rational[93639, 31250]}, {13, 3}}, {{2, 0}, {2.22, 
       0.003552}, {2.44, 0.014016}, {2.66, 0.031104}, {2.88, 0.054528}, {3.1, 
       0.084}, {3.32, 0.119232}, {3.54, 0.159936}, {3.76, 0.205824}, {3.98, 
       0.256608}, {4.2, 0.312}, {4.42, 0.371712}, {4.64, 0.435456}, {4.86, 
       0.502944}, {5.08, 0.573888}, {5.3, 0.648}, {5.52, 0.724992}, {5.74, 
       0.804576}, {5.96, 0.886464}, {6.18, 0.970368}, {6.4, 1.056}, {6.62, 
       1.143072}, {6.84, 1.231296}, {7.06, 1.320384}, {7.28, 1.410048}, {7.5, 
       1.5}, {7.72, 1.589952}, {7.94, 1.679616}, {8.16, 1.768704}, {8.38, 
       1.856928}, {8.6, 1.944}, {8.82, 2.029632}, {9.04, 2.113536}, {9.26, 
       2.195424}, {9.48, 2.275008}, {9.7, 2.352}, {9.92, 2.426112}, {10.14, 
       2.497056}, {10.36, 2.564544}, {10.58, 2.628288}, {10.8, 2.688}, {11.02,
        2.743392}, {11.24, 2.794176}, {11.46, 2.840064}, {11.68, 2.880768}, {
       11.9, 2.916}, {12.12, 2.945472}, {12.34, 2.968896}, {12.56, 
       2.985984}, {12.78, 2.996448}, {13, 3}}]], LineBox[{{13, 3}, {15, 3}}]}, 
   {Arrowheads[0.015], ArrowBox[{{14., 1.7999999999999998`}, {14, 3}}], 
    ArrowBox[{{14., 1.2000000000000002`}, {14, 0}}], 
    InsetBox["\<\"\\!\\(\\*\\nStyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\"\>", {14., 1.5}]}, 
   {Dashing[0.00375], LineBox[{{13.6, 0}, {14.4, 0}}]}, {
    {GrayLevel[0.7], 
     DiskBox[{0.91, 0.09}, {0.66, 0.6000000000000001}, 
      NCache[{72 Degree, Pi}, {1.2566370614359172`, 3.141592653589793}]], 
     DiskBox[{1.2850000000000001`, 0.09}, {0.46499999999999997`, 0.375}, 
      NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], 
     PolygonBox[{{0.25, 0.09}, {1.75, 0.09}, {1.2850000000000001`, 
      0.46499999999999997`}, {1.1139512162874654`, 0.6606339097770921}}]}, 
    {GrayLevel[0.4], DiskBox[{0.4750000000000001, 0.12}, 0.12], 
     DiskBox[{1.525, 0.12}, 0.12]}}, {
    {RGBColor[0.865, 0.865, 0.865], 
     DiskBox[{13.91, 3.09}, {0.66, 0.6000000000000001}, 
      NCache[{72 Degree, Pi}, {1.2566370614359172`, 3.141592653589793}]], 
     DiskBox[{14.285, 3.09}, {0.46499999999999997`, 0.375}, 
      NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]], 
     PolygonBox[{{13.25, 3.09}, {14.75, 3.09}, {14.285, 3.465}, {
      14.113951216287465`, 3.660633909777092}}]}, 
    {RGBColor[0.73, 0.73, 0.73], DiskBox[{13.475, 3.12}, 0.12], 
     DiskBox[{14.525, 3.12}, 0.12]}}, 
   {Arrowheads[
    0.03], {InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(0\\)]\\)\"\>", 
      Offset[{0., 15.}, {1., 1.1}]], ArrowBox[{{0.4, 1.1}, {1.6, 1.1}}]}, {
     InsetBox["\<\"\\!\\(\\*\\nStyleBox[\\\"v\\\",\\nFontSlant->\\\"Italic\\\"\
]\\)\[VeryThinSpace]=\[VeryThinSpace]?\"\>", Offset[{0., 15.}, {14., 4.1}]], 
     ArrowBox[{{13.4, 4.1}, {14.6, 4.1}}]}}},
  BaseStyle->{12, FontFamily -> "Times"}]], "Output",
 CellChangeTimes->{3.664452646522105*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SimpleCar"}]], "Input",
 CellChangeTimes->{{3.623940103976307*^9, 3.623940108157827*^9}}],

Cell[BoxData[
 StyleBox["\<\"SimpleCar[r:{0,0},opts] makes a car with r below the center at \
road level. The car has width 1\[Times]Scale, where Scale is an option with \
default value 1.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.664452666602366*^9},
 CellTags->"Info-60de20f2-58ba-4d23-b536-40ca1e213419"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "SimpleCar", "]"}]], "Input",
 CellChangeTimes->{{3.623940242170196*^9, 3.623940247673868*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Reverse", "\[Rule]", "False"}], ",", 
   RowBox[{"Scale", "\[Rule]", "1"}], ",", 
   RowBox[{"TireColor", "\[Rule]", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {GrayLevel[0.4], RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->GrayLevel[0.2666666666666667],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification]}],
        PlotRangePadding->None],
       "GrayLevel[0.4]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0.4]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["GrayLevelColorValueSelector"], {
            0, {Left, Bottom}}, {Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     GrayLevel[0.4],
     Editable->False,
     Selectable->False]}], ",", 
   RowBox[{"CarColor", "\[Rule]", 
    InterpretationBox[
     ButtonBox[
      TooltipBox[
       GraphicsBox[{
         {GrayLevel[0], RectangleBox[{0, 0}]}, 
         {GrayLevel[0], RectangleBox[{1, -1}]}, 
         {GrayLevel[0.7], RectangleBox[{0, -1}, {2, 1}]}},
        AspectRatio->1,
        Frame->True,
        FrameStyle->GrayLevel[0.4666666666666667],
        FrameTicks->None,
        ImageSize->
         Dynamic[{
          Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
           Magnification]}],
        PlotRangePadding->None],
       "GrayLevel[0.7]"],
      Appearance->None,
      BaseStyle->{},
      BaselinePosition->Baseline,
      ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
        If[
         Not[
          AbsoluteCurrentValue["Deployed"]], 
         SelectionMove[Typeset`box$, All, Expression]; 
         FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
         FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0.7]; 
         FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
         MathLink`CallFrontEnd[
           FrontEnd`AttachCell[Typeset`box$, 
            FrontEndResource["GrayLevelColorValueSelector"], {
            0, {Left, Bottom}}, {Left, Top}, 
            "ClosingActions" -> {
             "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
      DefaultBaseStyle->{},
      Evaluator->Automatic,
      Method->"Preemptive"],
     GrayLevel[0.7],
     Editable->False,
     Selectable->False]}]}], "}"}]], "Output",
 CellChangeTimes->{3.664452669138729*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other", "Subsection",
 CellChangeTimes->{{3.623941254051158*^9, 3.62394128769175*^9}, {
  3.6644519310919533`*^9, 3.6644519317463093`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "LinePolygonMappingRules"}]], "Input",
 CellChangeTimes->{{3.6238943017398987`*^9, 3.623894308099421*^9}}],

Cell[BoxData[
 StyleBox["\<\"LinePolygonMappingRules[f] gives the rules to map the Line, \
Polygon, Text and GraphicsComplex from x to f[x]. Acting on Rectangle it is \
converted to Polygon and then transformed. LinePolygonMap[f,expr] and \
expr/.LinePolygonMappingRules[f] are equivalent.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.664452671966926*^9},
 CellTags->"Info-acfd22f9-65d5-4816-a574-41d144f29b8a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "MinPolynomial"}]], "Input",
 CellChangeTimes->{{3.623895519163382*^9, 3.623895519799762*^9}}],

Cell[BoxData[
 StyleBox["\<\"MinPolynomial[{x1,f[x1],f'[x1],f''[x1],...},{x2,f[x2],f'[x2],f'\
'[x2],... },... ] creates an anonymous polynomial function of x of minimal \
order to match the function value and derivative values at x1, x2, ...\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6644526744556923`*^9},
 CellTags->"Info-f4c4a5c8-b684-4179-8e93-e5d9e0c4b63c"]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{808, 702},
WindowMargins->{{203, Automatic}, {-25, Automatic}},
FrontEndVersion->"10.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 10, \
2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info-acfd22f9-65d5-4816-a574-41d144f29b8a"->{
  Cell[153662, 3478, 427, 7, 93, "Print",
   CellTags->"Info-acfd22f9-65d5-4816-a574-41d144f29b8a"]},
 "Info-afa75f55-c95b-4435-b8fb-fd78f5fb709d"->{
  Cell[2340, 61, 402, 6, 93, "Print",
   CellTags->"Info-afa75f55-c95b-4435-b8fb-fd78f5fb709d"]},
 "Info-a2e2a8dc-467a-4e25-b3e4-bf95cf1af882"->{
  Cell[1621, 48, 716, 11, 177, "Print",
   CellTags->"Info-a2e2a8dc-467a-4e25-b3e4-bf95cf1af882"]},
 "Info-a82cc89e-ce9f-41cc-930e-9aefb6d0c4e2"->{
  Cell[99527, 2365, 257, 4, 51, "Print",
   CellTags->"Info-a82cc89e-ce9f-41cc-930e-9aefb6d0c4e2"]},
 "Info-b0807b79-7460-44b9-9bf9-f42a7330a29d"->{
  Cell[3192, 85, 291, 5, 72, "Print",
   CellTags->"Info-b0807b79-7460-44b9-9bf9-f42a7330a29d"]},
 "Info-b135235a-e966-4b91-aad0-8098d53dc990"->{
  Cell[92604, 2190, 255, 4, 51, "Print",
   CellTags->"Info-b135235a-e966-4b91-aad0-8098d53dc990"]},
 "Info-c8fcd507-db8b-4fb3-9955-bdee6420cc2f"->{
  Cell[33656, 868, 676, 10, 156, "Print",
   CellTags->"Info-c8fcd507-db8b-4fb3-9955-bdee6420cc2f"]},
 "Info-db8e6cab-ce76-4a5b-90ce-6e612184be4b"->{
  Cell[97647, 2316, 531, 8, 114, "Print",
   CellTags->"Info-db8e6cab-ce76-4a5b-90ce-6e612184be4b"]},
 "Info-f4c4a5c8-b684-4179-8e93-e5d9e0c4b63c"->{
  Cell[154251, 3494, 382, 6, 72, "Print",
   CellTags->"Info-f4c4a5c8-b684-4179-8e93-e5d9e0c4b63c"]},
 "Info-f4460144-5bfb-4a6c-9dcd-e3fd64f530d7"->{
  Cell[20044, 499, 508, 8, 114, "Print",
   CellTags->"Info-f4460144-5bfb-4a6c-9dcd-e3fd64f530d7"]},
 "Info-15083792-f25b-41dc-bc66-d4d432c2d2e3"->{
  Cell[78077, 1851, 475, 7, 93, "Print",
   CellTags->"Info-15083792-f25b-41dc-bc66-d4d432c2d2e3"]},
 "Info-41a52591-3594-4d9c-8a30-d9f54aedff00"->{
  Cell[93019, 2203, 509, 8, 114, "Print",
   CellTags->"Info-41a52591-3594-4d9c-8a30-d9f54aedff00"]},
 "Info-415fab57-c6fc-4d83-8920-f0f6afc8ea83"->{
  Cell[64197, 1574, 475, 7, 93, "Print",
   CellTags->"Info-415fab57-c6fc-4d83-8920-f0f6afc8ea83"]},
 "Info-5c7a5d50-86cb-4974-9d1a-27a679b079d0"->{
  Cell[99235, 2358, 289, 5, 72, "Print",
   CellTags->"Info-5c7a5d50-86cb-4974-9d1a-27a679b079d0"]},
 "Info-60de20f2-58ba-4d23-b536-40ca1e213419"->{
  Cell[149590, 3361, 324, 5, 72, "Print",
   CellTags->"Info-60de20f2-58ba-4d23-b536-40ca1e213419"]},
 "Info-78183e64-64c1-4ad0-b98d-28ac50481b71"->{
  Cell[63653, 1559, 384, 6, 93, "Print",
   CellTags->"Info-78183e64-64c1-4ad0-b98d-28ac50481b71"]},
 "Info-80b612c1-3f1f-4b26-99ae-023af0b5a187"->{
  Cell[82630, 1975, 324, 5, 72, "Print",
   CellTags->"Info-80b612c1-3f1f-4b26-99ae-023af0b5a187"]},
 "Info-803b9123-fde9-4019-8871-719cbe3bcc83"->{
  Cell[98337, 2333, 475, 7, 114, "Print",
   CellTags->"Info-803b9123-fde9-4019-8871-719cbe3bcc83"]},
 "Info-952de8a6-885e-4dc4-b0d9-2c4f8a31ef1f"->{
  Cell[30757, 774, 246, 4, 51, "Print",
   CellTags->"Info-952de8a6-885e-4dc4-b0d9-2c4f8a31ef1f"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info-acfd22f9-65d5-4816-a574-41d144f29b8a", 155031, 3516},
 {"Info-afa75f55-c95b-4435-b8fb-fd78f5fb709d", 155181, 3519},
 {"Info-a2e2a8dc-467a-4e25-b3e4-bf95cf1af882", 155327, 3522},
 {"Info-a82cc89e-ce9f-41cc-930e-9aefb6d0c4e2", 155475, 3525},
 {"Info-b0807b79-7460-44b9-9bf9-f42a7330a29d", 155624, 3528},
 {"Info-b135235a-e966-4b91-aad0-8098d53dc990", 155770, 3531},
 {"Info-c8fcd507-db8b-4fb3-9955-bdee6420cc2f", 155919, 3534},
 {"Info-db8e6cab-ce76-4a5b-90ce-6e612184be4b", 156069, 3537},
 {"Info-f4c4a5c8-b684-4179-8e93-e5d9e0c4b63c", 156219, 3540},
 {"Info-f4460144-5bfb-4a6c-9dcd-e3fd64f530d7", 156369, 3543},
 {"Info-15083792-f25b-41dc-bc66-d4d432c2d2e3", 156518, 3546},
 {"Info-41a52591-3594-4d9c-8a30-d9f54aedff00", 156667, 3549},
 {"Info-415fab57-c6fc-4d83-8920-f0f6afc8ea83", 156817, 3552},
 {"Info-5c7a5d50-86cb-4974-9d1a-27a679b079d0", 156966, 3555},
 {"Info-60de20f2-58ba-4d23-b536-40ca1e213419", 157115, 3558},
 {"Info-78183e64-64c1-4ad0-b98d-28ac50481b71", 157265, 3561},
 {"Info-80b612c1-3f1f-4b26-99ae-023af0b5a187", 157414, 3564},
 {"Info-803b9123-fde9-4019-8871-719cbe3bcc83", 157563, 3567},
 {"Info-952de8a6-885e-4dc4-b0d9-2c4f8a31ef1f", 157713, 3570}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 529, 9, 85, "Text"],
Cell[1090, 31, 290, 5, 57, "Input"],
Cell[CellGroupData[{
Cell[1405, 40, 191, 4, 57, "Input"],
Cell[CellGroupData[{
Cell[1621, 48, 716, 11, 177, "Print",
 CellTags->"Info-a2e2a8dc-467a-4e25-b3e4-bf95cf1af882"],
Cell[2340, 61, 402, 6, 93, "Print",
 CellTags->"Info-afa75f55-c95b-4435-b8fb-fd78f5fb709d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2791, 73, 252, 4, 54, "Subsection"],
Cell[CellGroupData[{
Cell[3068, 81, 121, 2, 35, "Input"],
Cell[3192, 85, 291, 5, 72, "Print",
 CellTags->"Info-b0807b79-7460-44b9-9bf9-f42a7330a29d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3520, 95, 766, 19, 83, "Input"],
Cell[4289, 116, 446, 10, 148, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4772, 131, 1080, 24, 153, "Input"],
Cell[5855, 157, 366, 9, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6258, 171, 141, 2, 36, "Input"],
Cell[6402, 175, 334, 8, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6773, 188, 8346, 204, 477, "Input"],
Cell[15122, 394, 4762, 96, 293, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19921, 495, 120, 2, 35, "Input"],
Cell[20044, 499, 508, 8, 114, "Print",
 CellTags->"Info-f4460144-5bfb-4a6c-9dcd-e3fd64f530d7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20589, 512, 6648, 174, 519, "Input"],
Cell[27240, 688, 3233, 71, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30522, 765, 82, 1, 54, "Subsection"],
Cell[CellGroupData[{
Cell[30629, 770, 125, 2, 36, "Input"],
Cell[30757, 774, 246, 4, 51, "Print",
 CellTags->"Info-952de8a6-885e-4dc4-b0d9-2c4f8a31ef1f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31040, 783, 1286, 37, 78, "Input"],
Cell[32329, 822, 562, 14, 155, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32928, 841, 117, 2, 36, "Input"],
Cell[33048, 845, 322, 8, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33419, 859, 94, 1, 54, "Subsection"],
Cell[CellGroupData[{
Cell[33538, 864, 115, 2, 36, "Input"],
Cell[33656, 868, 676, 10, 156, "Print",
 CellTags->"Info-c8fcd507-db8b-4fb3-9955-bdee6420cc2f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34369, 883, 156, 3, 36, "Input"],
Cell[34528, 888, 5507, 146, 162, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40072, 1039, 1321, 30, 78, "Input"],
Cell[41396, 1071, 2335, 43, 208, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43768, 1119, 7167, 160, 444, "Input"],
Cell[50938, 1281, 3185, 62, 797, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[54172, 1349, 393, 6, 54, "Subsection"],
Cell[CellGroupData[{
Cell[54590, 1359, 5540, 124, 330, "Input"],
Cell[60133, 1485, 3362, 65, 274, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63532, 1555, 118, 2, 36, "Input"],
Cell[63653, 1559, 384, 6, 93, "Print",
 CellTags->"Info-78183e64-64c1-4ad0-b98d-28ac50481b71"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64074, 1570, 120, 2, 36, "Input"],
Cell[64197, 1574, 475, 7, 93, "Print",
 CellTags->"Info-415fab57-c6fc-4d83-8920-f0f6afc8ea83"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64709, 1586, 5793, 125, 225, "Input"],
Cell[70505, 1713, 2591, 45, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73133, 1763, 3294, 53, 99, "Input"],
Cell[76430, 1818, 1485, 24, 237, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77952, 1847, 122, 2, 36, "Input"],
Cell[78077, 1851, 475, 7, 93, "Print",
 CellTags->"Info-15083792-f25b-41dc-bc66-d4d432c2d2e3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78589, 1863, 136, 2, 36, "Input"],
Cell[78728, 1867, 3273, 88, 57, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[82050, 1961, 435, 6, 54, "Subsection"],
Cell[CellGroupData[{
Cell[82510, 1971, 117, 2, 36, "Input"],
Cell[82630, 1975, 324, 5, 72, "Print",
 CellTags->"Info-80b612c1-3f1f-4b26-99ae-023af0b5a187"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82991, 1985, 4143, 104, 320, "Input"],
Cell[87137, 2091, 5302, 90, 256, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92476, 2186, 125, 2, 36, "Input"],
Cell[92604, 2190, 255, 4, 51, "Print",
 CellTags->"Info-b135235a-e966-4b91-aad0-8098d53dc990"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92896, 2199, 120, 2, 35, "Input"],
Cell[93019, 2203, 509, 8, 114, "Print",
 CellTags->"Info-41a52591-3594-4d9c-8a30-d9f54aedff00"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[93577, 2217, 449, 6, 54, "Subsection"],
Cell[CellGroupData[{
Cell[94051, 2227, 1692, 43, 99, "Input"],
Cell[95746, 2272, 1744, 35, 233, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97527, 2312, 117, 2, 36, "Input"],
Cell[97647, 2316, 531, 8, 114, "Print",
 CellTags->"Info-db8e6cab-ce76-4a5b-90ce-6e612184be4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98215, 2329, 119, 2, 35, "Input"],
Cell[98337, 2333, 475, 7, 114, "Print",
 CellTags->"Info-803b9123-fde9-4019-8871-719cbe3bcc83"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[98861, 2346, 135, 1, 54, "Subsection"],
Cell[CellGroupData[{
Cell[99021, 2351, 189, 3, 57, "Input"],
Cell[CellGroupData[{
Cell[99235, 2358, 289, 5, 72, "Print",
 CellTags->"Info-5c7a5d50-86cb-4974-9d1a-27a679b079d0"],
Cell[99527, 2365, 257, 4, 51, "Print",
 CellTags->"Info-a82cc89e-ce9f-41cc-930e-9aefb6d0c4e2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[99833, 2375, 11967, 263, 583, "Input"],
Cell[111803, 2640, 19550, 350, 144, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131390, 2995, 8846, 194, 560, "Input"],
Cell[140239, 3191, 9193, 161, 178, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[149469, 3357, 118, 2, 36, "Input"],
Cell[149590, 3361, 324, 5, 72, "Print",
 CellTags->"Info-60de20f2-58ba-4d23-b536-40ca1e213419"]
}, Open  ]],
Cell[CellGroupData[{
Cell[149951, 3371, 134, 2, 36, "Input"],
Cell[150088, 3375, 3218, 87, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[153355, 3468, 145, 2, 54, "Subsection"],
Cell[CellGroupData[{
Cell[153525, 3474, 134, 2, 36, "Input"],
Cell[153662, 3478, 427, 7, 93, "Print",
 CellTags->"Info-acfd22f9-65d5-4816-a574-41d144f29b8a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154126, 3490, 122, 2, 36, "Input"],
Cell[154251, 3494, 382, 6, 72, "Print",
 CellTags->"Info-f4c4a5c8-b684-4179-8e93-e5d9e0c4b63c"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
